#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class RequestEncryption(TLObject):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``177``
        - ID: ``F64DAF43``

    Parameters:
        user_id (:obj:`InputUser <pyrogram.raw.base.InputUser>`):
            N/A

        random_id (``int`` ``32-bit``):
            N/A

        g_a (``bytes``):
            N/A

    Returns:
        :obj:`EncryptedChat <pyrogram.raw.base.EncryptedChat>`
    """

    __slots__: List[str] = ["user_id", "random_id", "g_a"]

    ID = 0xf64daf43
    QUALNAME = "functions.messages.RequestEncryption"

    def __init__(self, *, user_id: "raw.base.InputUser", random_id: int, g_a: bytes) -> None:
        self.user_id = user_id  # InputUser
        self.random_id = random_id  # int
        self.g_a = g_a  # bytes

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "RequestEncryption":
        # No flags
        
        user_id = TLObject.read(b)
        
        random_id = Int.read(b)
        
        g_a = Bytes.read(b)
        
        return RequestEncryption(user_id=user_id, random_id=random_id, g_a=g_a)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.user_id.write())
        
        b.write(Int(self.random_id))
        
        b.write(Bytes(self.g_a))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO
from typing import Any

from .primitives.int import Int, Long
from .tl_object import TLObject


class FutureSalt(TLObject):
    ID = 0x0949D9DC

    __slots__ = ["valid_since", "valid_until", "salt"]

    QUALNAME = "FutureSalt"

    def __init__(self, valid_since: int, valid_until: int, salt: int):
        self.valid_since = valid_since
        self.valid_until = valid_until
        self.salt = salt

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "FutureSalt":
        valid_since = Int.read(data)
        valid_until = Int.read(data)
        salt = Long.read(data)

        return FutureSalt(valid_since, valid_until, salt)

    def write(self, *args: Any) -> bytes:
        b = BytesIO()

        b.write(Int(self.valid_since))
        b.write(Int(self.valid_until))
        b.write(Long(self.salt))

        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class MsgDetailedInfo(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.MsgDetailedInfo`.

    Details:
        - Layer: ``177``
        - ID: ``276D3EC6``

    Parameters:
        msg_id (``int`` ``64-bit``):
            N/A

        answer_msg_id (``int`` ``64-bit``):
            N/A

        bytes (``int`` ``32-bit``):
            N/A

        status (``int`` ``32-bit``):
            N/A

    """

    __slots__: List[str] = ["msg_id", "answer_msg_id", "bytes", "status"]

    ID = 0x276d3ec6
    QUALNAME = "types.MsgDetailedInfo"

    def __init__(self, *, msg_id: int, answer_msg_id: int, bytes: int, status: int) -> None:
        self.msg_id = msg_id  # long
        self.answer_msg_id = answer_msg_id  # long
        self.bytes = bytes  # int
        self.status = status  # int

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "MsgDetailedInfo":
        # No flags
        
        msg_id = Long.read(b)
        
        answer_msg_id = Long.read(b)
        
        bytes = Int.read(b)
        
        status = Int.read(b)
        
        return MsgDetailedInfo(msg_id=msg_id, answer_msg_id=answer_msg_id, bytes=bytes, status=status)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Long(self.msg_id))
        
        b.write(Long(self.answer_msg_id))
        
        b.write(Int(self.bytes))
        
        b.write(Int(self.status))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class EmojiList(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.EmojiList`.

    Details:
        - Layer: ``177``
        - ID: ``7A1E11D1``

    Parameters:
        hash (``int`` ``64-bit``):
            N/A

        document_id (List of ``int`` ``64-bit``):
            N/A

    Functions:
        This object can be returned by 5 functions.

        .. currentmodule:: pyrogram.raw.functions

        .. autosummary::
            :nosignatures:

            account.GetDefaultProfilePhotoEmojis
            account.GetDefaultGroupPhotoEmojis
            account.GetDefaultBackgroundEmojis
            account.GetChannelRestrictedStatusEmojis
            messages.SearchCustomEmoji
    """

    __slots__: List[str] = ["hash", "document_id"]

    ID = 0x7a1e11d1
    QUALNAME = "types.EmojiList"

    def __init__(self, *, hash: int, document_id: List[int]) -> None:
        self.hash = hash  # long
        self.document_id = document_id  # Vector<long>

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "EmojiList":
        # No flags
        
        hash = Long.read(b)
        
        document_id = TLObject.read(b, Long)
        
        return EmojiList(hash=hash, document_id=document_id)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Long(self.hash))
        
        b.write(Vector(self.document_id, Long))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class JsonObjectValue(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.JSONObjectValue`.

    Details:
        - Layer: ``177``
        - ID: ``C0DE1BD9``

    Parameters:
        key (``str``):
            N/A

        value (:obj:`JSONValue <pyrogram.raw.base.JSONValue>`):
            N/A

    """

    __slots__: List[str] = ["key", "value"]

    ID = 0xc0de1bd9
    QUALNAME = "types.JsonObjectValue"

    def __init__(self, *, key: str, value: "raw.base.JSONValue") -> None:
        self.key = key  # string
        self.value = value  # JSONValue

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "JsonObjectValue":
        # No flags
        
        key = String.read(b)
        
        value = TLObject.read(b)
        
        return JsonObjectValue(key=key, value=value)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.key))
        
        b.write(self.value.write())
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class ChannelAdminLogEventsFilter(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.ChannelAdminLogEventsFilter`.

    Details:
        - Layer: ``177``
        - ID: ``EA107AE4``

    Parameters:
        join (``bool``, *optional*):
            N/A

        leave (``bool``, *optional*):
            N/A

        invite (``bool``, *optional*):
            N/A

        ban (``bool``, *optional*):
            N/A

        unban (``bool``, *optional*):
            N/A

        kick (``bool``, *optional*):
            N/A

        unkick (``bool``, *optional*):
            N/A

        promote (``bool``, *optional*):
            N/A

        demote (``bool``, *optional*):
            N/A

        info (``bool``, *optional*):
            N/A

        settings (``bool``, *optional*):
            N/A

        pinned (``bool``, *optional*):
            N/A

        edit (``bool``, *optional*):
            N/A

        delete (``bool``, *optional*):
            N/A

        group_call (``bool``, *optional*):
            N/A

        invites (``bool``, *optional*):
            N/A

        send (``bool``, *optional*):
            N/A

        forums (``bool``, *optional*):
            N/A

    """

    __slots__: List[str] = ["join", "leave", "invite", "ban", "unban", "kick", "unkick", "promote", "demote", "info", "settings", "pinned", "edit", "delete", "group_call", "invites", "send", "forums"]

    ID = 0xea107ae4
    QUALNAME = "types.ChannelAdminLogEventsFilter"

    def __init__(self, *, join: Optional[bool] = None, leave: Optional[bool] = None, invite: Optional[bool] = None, ban: Optional[bool] = None, unban: Optional[bool] = None, kick: Optional[bool] = None, unkick: Optional[bool] = None, promote: Optional[bool] = None, demote: Optional[bool] = None, info: Optional[bool] = None, settings: Optional[bool] = None, pinned: Optional[bool] = None, edit: Optional[bool] = None, delete: Optional[bool] = None, group_call: Optional[bool] = None, invites: Optional[bool] = None, send: Optional[bool] = None, forums: Optional[bool] = None) -> None:
        self.join = join  # flags.0?true
        self.leave = leave  # flags.1?true
        self.invite = invite  # flags.2?true
        self.ban = ban  # flags.3?true
        self.unban = unban  # flags.4?true
        self.kick = kick  # flags.5?true
        self.unkick = unkick  # flags.6?true
        self.promote = promote  # flags.7?true
        self.demote = demote  # flags.8?true
        self.info = info  # flags.9?true
        self.settings = settings  # flags.10?true
        self.pinned = pinned  # flags.11?true
        self.edit = edit  # flags.12?true
        self.delete = delete  # flags.13?true
        self.group_call = group_call  # flags.14?true
        self.invites = invites  # flags.15?true
        self.send = send  # flags.16?true
        self.forums = forums  # flags.17?true

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "ChannelAdminLogEventsFilter":
        
        flags = Int.read(b)
        
        join = True if flags & (1 << 0) else False
        leave = True if flags & (1 << 1) else False
        invite = True if flags & (1 << 2) else False
        ban = True if flags & (1 << 3) else False
        unban = True if flags & (1 << 4) else False
        kick = True if flags & (1 << 5) else False
        unkick = True if flags & (1 << 6) else False
        promote = True if flags & (1 << 7) else False
        demote = True if flags & (1 << 8) else False
        info = True if flags & (1 << 9) else False
        settings = True if flags & (1 << 10) else False
        pinned = True if flags & (1 << 11) else False
        edit = True if flags & (1 << 12) else False
        delete = True if flags & (1 << 13) else False
        group_call = True if flags & (1 << 14) else False
        invites = True if flags & (1 << 15) else False
        send = True if flags & (1 << 16) else False
        forums = True if flags & (1 << 17) else False
        return ChannelAdminLogEventsFilter(join=join, leave=leave, invite=invite, ban=ban, unban=unban, kick=kick, unkick=unkick, promote=promote, demote=demote, info=info, settings=settings, pinned=pinned, edit=edit, delete=delete, group_call=group_call, invites=invites, send=send, forums=forums)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.join else 0
        flags |= (1 << 1) if self.leave else 0
        flags |= (1 << 2) if self.invite else 0
        flags |= (1 << 3) if self.ban else 0
        flags |= (1 << 4) if self.unban else 0
        flags |= (1 << 5) if self.kick else 0
        flags |= (1 << 6) if self.unkick else 0
        flags |= (1 << 7) if self.promote else 0
        flags |= (1 << 8) if self.demote else 0
        flags |= (1 << 9) if self.info else 0
        flags |= (1 << 10) if self.settings else 0
        flags |= (1 << 11) if self.pinned else 0
        flags |= (1 << 12) if self.edit else 0
        flags |= (1 << 13) if self.delete else 0
        flags |= (1 << 14) if self.group_call else 0
        flags |= (1 << 15) if self.invites else 0
        flags |= (1 << 16) if self.send else 0
        flags |= (1 << 17) if self.forums else 0
        b.write(Int(flags))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class GetWebPage(TLObject):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``177``
        - ID: ``8D9692A3``

    Parameters:
        url (``str``):
            N/A

        hash (``int`` ``32-bit``):
            N/A

    Returns:
        :obj:`messages.WebPage <pyrogram.raw.base.messages.WebPage>`
    """

    __slots__: List[str] = ["url", "hash"]

    ID = 0x8d9692a3
    QUALNAME = "functions.messages.GetWebPage"

    def __init__(self, *, url: str, hash: int) -> None:
        self.url = url  # string
        self.hash = hash  # int

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "GetWebPage":
        # No flags
        
        url = String.read(b)
        
        hash = Int.read(b)
        
        return GetWebPage(url=url, hash=hash)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.url))
        
        b.write(Int(self.hash))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class InputMediaPoll(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.InputMedia`.

    Details:
        - Layer: ``177``
        - ID: ``F94E5F1``

    Parameters:
        poll (:obj:`Poll <pyrogram.raw.base.Poll>`):
            N/A

        correct_answers (List of ``bytes``, *optional*):
            N/A

        solution (``str``, *optional*):
            N/A

        solution_entities (List of :obj:`MessageEntity <pyrogram.raw.base.MessageEntity>`, *optional*):
            N/A

    """

    __slots__: List[str] = ["poll", "correct_answers", "solution", "solution_entities"]

    ID = 0xf94e5f1
    QUALNAME = "types.InputMediaPoll"

    def __init__(self, *, poll: "raw.base.Poll", correct_answers: Optional[List[bytes]] = None, solution: Optional[str] = None, solution_entities: Optional[List["raw.base.MessageEntity"]] = None) -> None:
        self.poll = poll  # Poll
        self.correct_answers = correct_answers  # flags.0?Vector<bytes>
        self.solution = solution  # flags.1?string
        self.solution_entities = solution_entities  # flags.1?Vector<MessageEntity>

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "InputMediaPoll":
        
        flags = Int.read(b)
        
        poll = TLObject.read(b)
        
        correct_answers = TLObject.read(b, Bytes) if flags & (1 << 0) else []
        
        solution = String.read(b) if flags & (1 << 1) else None
        solution_entities = TLObject.read(b) if flags & (1 << 1) else []
        
        return InputMediaPoll(poll=poll, correct_answers=correct_answers, solution=solution, solution_entities=solution_entities)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.correct_answers else 0
        flags |= (1 << 1) if self.solution is not None else 0
        flags |= (1 << 1) if self.solution_entities else 0
        b.write(Int(flags))
        
        b.write(self.poll.write())
        
        if self.correct_answers is not None:
            b.write(Vector(self.correct_answers, Bytes))
        
        if self.solution is not None:
            b.write(String(self.solution))
        
        if self.solution_entities is not None:
            b.write(Vector(self.solution_entities))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class DialogFolder(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.Dialog`.

    Details:
        - Layer: ``177``
        - ID: ``71BD134C``

    Parameters:
        folder (:obj:`Folder <pyrogram.raw.base.Folder>`):
            N/A

        peer (:obj:`Peer <pyrogram.raw.base.Peer>`):
            N/A

        top_message (``int`` ``32-bit``):
            N/A

        unread_muted_peers_count (``int`` ``32-bit``):
            N/A

        unread_unmuted_peers_count (``int`` ``32-bit``):
            N/A

        unread_muted_messages_count (``int`` ``32-bit``):
            N/A

        unread_unmuted_messages_count (``int`` ``32-bit``):
            N/A

        pinned (``bool``, *optional*):
            N/A

    """

    __slots__: List[str] = ["folder", "peer", "top_message", "unread_muted_peers_count", "unread_unmuted_peers_count", "unread_muted_messages_count", "unread_unmuted_messages_count", "pinned"]

    ID = 0x71bd134c
    QUALNAME = "types.DialogFolder"

    def __init__(self, *, folder: "raw.base.Folder", peer: "raw.base.Peer", top_message: int, unread_muted_peers_count: int, unread_unmuted_peers_count: int, unread_muted_messages_count: int, unread_unmuted_messages_count: int, pinned: Optional[bool] = None) -> None:
        self.folder = folder  # Folder
        self.peer = peer  # Peer
        self.top_message = top_message  # int
        self.unread_muted_peers_count = unread_muted_peers_count  # int
        self.unread_unmuted_peers_count = unread_unmuted_peers_count  # int
        self.unread_muted_messages_count = unread_muted_messages_count  # int
        self.unread_unmuted_messages_count = unread_unmuted_messages_count  # int
        self.pinned = pinned  # flags.2?true

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "DialogFolder":
        
        flags = Int.read(b)
        
        pinned = True if flags & (1 << 2) else False
        folder = TLObject.read(b)
        
        peer = TLObject.read(b)
        
        top_message = Int.read(b)
        
        unread_muted_peers_count = Int.read(b)
        
        unread_unmuted_peers_count = Int.read(b)
        
        unread_muted_messages_count = Int.read(b)
        
        unread_unmuted_messages_count = Int.read(b)
        
        return DialogFolder(folder=folder, peer=peer, top_message=top_message, unread_muted_peers_count=unread_muted_peers_count, unread_unmuted_peers_count=unread_unmuted_peers_count, unread_muted_messages_count=unread_muted_messages_count, unread_unmuted_messages_count=unread_unmuted_messages_count, pinned=pinned)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 2) if self.pinned else 0
        b.write(Int(flags))
        
        b.write(self.folder.write())
        
        b.write(self.peer.write())
        
        b.write(Int(self.top_message))
        
        b.write(Int(self.unread_muted_peers_count))
        
        b.write(Int(self.unread_unmuted_peers_count))
        
        b.write(Int(self.unread_muted_messages_count))
        
        b.write(Int(self.unread_unmuted_messages_count))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

import logging
import time

log = logging.getLogger(__name__)


class MsgId:
    last_time = 0
    offset = 0

    def __new__(cls) -> int:
        now = int(time.time())
        cls.offset = (cls.offset + 4) if now == cls.last_time else 0
        msg_id = (now * 2 ** 32) + cls.offset
        cls.last_time = now

        return msg_id



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class InputBotInlineResult(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.InputBotInlineResult`.

    Details:
        - Layer: ``177``
        - ID: ``88BF9319``

    Parameters:
        id (``str``):
            N/A

        type (``str``):
            N/A

        send_message (:obj:`InputBotInlineMessage <pyrogram.raw.base.InputBotInlineMessage>`):
            N/A

        title (``str``, *optional*):
            N/A

        description (``str``, *optional*):
            N/A

        url (``str``, *optional*):
            N/A

        thumb (:obj:`InputWebDocument <pyrogram.raw.base.InputWebDocument>`, *optional*):
            N/A

        content (:obj:`InputWebDocument <pyrogram.raw.base.InputWebDocument>`, *optional*):
            N/A

    """

    __slots__: List[str] = ["id", "type", "send_message", "title", "description", "url", "thumb", "content"]

    ID = 0x88bf9319
    QUALNAME = "types.InputBotInlineResult"

    def __init__(self, *, id: str, type: str, send_message: "raw.base.InputBotInlineMessage", title: Optional[str] = None, description: Optional[str] = None, url: Optional[str] = None, thumb: "raw.base.InputWebDocument" = None, content: "raw.base.InputWebDocument" = None) -> None:
        self.id = id  # string
        self.type = type  # string
        self.send_message = send_message  # InputBotInlineMessage
        self.title = title  # flags.1?string
        self.description = description  # flags.2?string
        self.url = url  # flags.3?string
        self.thumb = thumb  # flags.4?InputWebDocument
        self.content = content  # flags.5?InputWebDocument

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "InputBotInlineResult":
        
        flags = Int.read(b)
        
        id = String.read(b)
        
        type = String.read(b)
        
        title = String.read(b) if flags & (1 << 1) else None
        description = String.read(b) if flags & (1 << 2) else None
        url = String.read(b) if flags & (1 << 3) else None
        thumb = TLObject.read(b) if flags & (1 << 4) else None
        
        content = TLObject.read(b) if flags & (1 << 5) else None
        
        send_message = TLObject.read(b)
        
        return InputBotInlineResult(id=id, type=type, send_message=send_message, title=title, description=description, url=url, thumb=thumb, content=content)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 1) if self.title is not None else 0
        flags |= (1 << 2) if self.description is not None else 0
        flags |= (1 << 3) if self.url is not None else 0
        flags |= (1 << 4) if self.thumb is not None else 0
        flags |= (1 << 5) if self.content is not None else 0
        b.write(Int(flags))
        
        b.write(String(self.id))
        
        b.write(String(self.type))
        
        if self.title is not None:
            b.write(String(self.title))
        
        if self.description is not None:
            b.write(String(self.description))
        
        if self.url is not None:
            b.write(String(self.url))
        
        if self.thumb is not None:
            b.write(self.thumb.write())
        
        if self.content is not None:
            b.write(self.content.write())
        
        b.write(self.send_message.write())
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class AuthorizationForm(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.account.AuthorizationForm`.

    Details:
        - Layer: ``177``
        - ID: ``AD2E1CD8``

    Parameters:
        required_types (List of :obj:`SecureRequiredType <pyrogram.raw.base.SecureRequiredType>`):
            N/A

        values (List of :obj:`SecureValue <pyrogram.raw.base.SecureValue>`):
            N/A

        errors (List of :obj:`SecureValueError <pyrogram.raw.base.SecureValueError>`):
            N/A

        users (List of :obj:`User <pyrogram.raw.base.User>`):
            N/A

        privacy_policy_url (``str``, *optional*):
            N/A

    Functions:
        This object can be returned by 1 function.

        .. currentmodule:: pyrogram.raw.functions

        .. autosummary::
            :nosignatures:

            account.GetAuthorizationForm
    """

    __slots__: List[str] = ["required_types", "values", "errors", "users", "privacy_policy_url"]

    ID = 0xad2e1cd8
    QUALNAME = "types.account.AuthorizationForm"

    def __init__(self, *, required_types: List["raw.base.SecureRequiredType"], values: List["raw.base.SecureValue"], errors: List["raw.base.SecureValueError"], users: List["raw.base.User"], privacy_policy_url: Optional[str] = None) -> None:
        self.required_types = required_types  # Vector<SecureRequiredType>
        self.values = values  # Vector<SecureValue>
        self.errors = errors  # Vector<SecureValueError>
        self.users = users  # Vector<User>
        self.privacy_policy_url = privacy_policy_url  # flags.0?string

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "AuthorizationForm":
        
        flags = Int.read(b)
        
        required_types = TLObject.read(b)
        
        values = TLObject.read(b)
        
        errors = TLObject.read(b)
        
        users = TLObject.read(b)
        
        privacy_policy_url = String.read(b) if flags & (1 << 0) else None
        return AuthorizationForm(required_types=required_types, values=values, errors=errors, users=users, privacy_policy_url=privacy_policy_url)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.privacy_policy_url is not None else 0
        b.write(Int(flags))
        
        b.write(Vector(self.required_types))
        
        b.write(Vector(self.values))
        
        b.write(Vector(self.errors))
        
        b.write(Vector(self.users))
        
        if self.privacy_policy_url is not None:
            b.write(String(self.privacy_policy_url))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class SetSecureValueErrors(TLObject):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``177``
        - ID: ``90C894B5``

    Parameters:
        id (:obj:`InputUser <pyrogram.raw.base.InputUser>`):
            N/A

        errors (List of :obj:`SecureValueError <pyrogram.raw.base.SecureValueError>`):
            N/A

    Returns:
        ``bool``
    """

    __slots__: List[str] = ["id", "errors"]

    ID = 0x90c894b5
    QUALNAME = "functions.users.SetSecureValueErrors"

    def __init__(self, *, id: "raw.base.InputUser", errors: List["raw.base.SecureValueError"]) -> None:
        self.id = id  # InputUser
        self.errors = errors  # Vector<SecureValueError>

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "SetSecureValueErrors":
        # No flags
        
        id = TLObject.read(b)
        
        errors = TLObject.read(b)
        
        return SetSecureValueErrors(id=id, errors=errors)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.id.write())
        
        b.write(Vector(self.errors))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

import datetime
import pyrogram
from pyrogram import raw, utils

from ..object import Object


class BotBusinessConnection(Object):
    """A bot business connection Information.

    Parameters:
        bot_connection_id (``str``):
            The business connection identifier.
        
        user (:obj:`~pyrogram.types.User`):
            The user that connected to the bot.

        dc_id (``int``):
            The user datacenter.

        date (:py:obj:`~datetime.datetime`):
            Date the connection was established in Unix time.

        can_reply (``bool``, *optional*):
            Whether the bot can reply.

        is_disabled (``bool``, *optional*):
            Whether the connection is disabled.
    """
    def __init__(
        self,
        *,
        client: "pyrogram.Client" = None,
        bot_connection_id: str,
        user: "pyrogram.types.User",
        dc_id: int,
        date: "datetime.datetime",
        can_reply: bool = None,
        is_disabled: bool = None
    ):
        super().__init__(client)

        self.bot_connection_id = bot_connection_id
        self.user = user
        self.dc_id = dc_id
        self.date = date
        self.can_reply = can_reply
        self.is_disabled = is_disabled

    @staticmethod
    async def _parse(
        client: "pyrogram.Client",
        bot_connection: "raw.types.BotBusinessConnection"
    ) -> "BotBusinessConnection":
        return BotBusinessConnection(
            bot_connection_id = bot_connection.connection_id,
            user = await client.get_users(bot_connection.user_id),
            dc_id = bot_connection.dc_id,
            date = utils.timestamp_to_datetime(bot_connection.date),
            can_reply = bot_connection.can_reply,
            is_disabled = bot_connection.disabled,
            client=client
        )



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

import pyrogram
from pyrogram import raw
from pyrogram.errors import AuthBytesInvalid
from pyrogram.session import Session
from pyrogram.session.auth import Auth


async def get_session(client: "pyrogram.Client", dc_id: int):
    if dc_id == await client.storage.dc_id():
        return client

    async with client.media_sessions_lock:
        if client.media_sessions.get(dc_id):
            return client.media_sessions[dc_id]

        session = client.media_sessions[dc_id] = Session(
            client, dc_id,
            await Auth(client, dc_id, await client.storage.test_mode()).create(),
            await client.storage.test_mode(), is_media=True
        )

        await session.start()

        for _ in range(3):
            exported_auth = await client.invoke(
                raw.functions.auth.ExportAuthorization(
                    dc_id=dc_id
                )
            )

            try:
                await session.invoke(
                    raw.functions.auth.ImportAuthorization(
                        id=exported_auth.id,
                        bytes=exported_auth.bytes
                    )
                )
            except AuthBytesInvalid:
                continue
            else:
                break
        else:
            await session.stop()
            raise AuthBytesInvalid

        return session



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class Search(TLObject):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``177``
        - ID: ``29EE847A``

    Parameters:
        peer (:obj:`InputPeer <pyrogram.raw.base.InputPeer>`):
            N/A

        q (``str``):
            N/A

        filter (:obj:`MessagesFilter <pyrogram.raw.base.MessagesFilter>`):
            N/A

        min_date (``int`` ``32-bit``):
            N/A

        max_date (``int`` ``32-bit``):
            N/A

        offset_id (``int`` ``32-bit``):
            N/A

        add_offset (``int`` ``32-bit``):
            N/A

        limit (``int`` ``32-bit``):
            N/A

        max_id (``int`` ``32-bit``):
            N/A

        min_id (``int`` ``32-bit``):
            N/A

        hash (``int`` ``64-bit``):
            N/A

        from_id (:obj:`InputPeer <pyrogram.raw.base.InputPeer>`, *optional*):
            N/A

        saved_peer_id (:obj:`InputPeer <pyrogram.raw.base.InputPeer>`, *optional*):
            N/A

        saved_reaction (List of :obj:`Reaction <pyrogram.raw.base.Reaction>`, *optional*):
            N/A

        top_msg_id (``int`` ``32-bit``, *optional*):
            N/A

    Returns:
        :obj:`messages.Messages <pyrogram.raw.base.messages.Messages>`
    """

    __slots__: List[str] = ["peer", "q", "filter", "min_date", "max_date", "offset_id", "add_offset", "limit", "max_id", "min_id", "hash", "from_id", "saved_peer_id", "saved_reaction", "top_msg_id"]

    ID = 0x29ee847a
    QUALNAME = "functions.messages.Search"

    def __init__(self, *, peer: "raw.base.InputPeer", q: str, filter: "raw.base.MessagesFilter", min_date: int, max_date: int, offset_id: int, add_offset: int, limit: int, max_id: int, min_id: int, hash: int, from_id: "raw.base.InputPeer" = None, saved_peer_id: "raw.base.InputPeer" = None, saved_reaction: Optional[List["raw.base.Reaction"]] = None, top_msg_id: Optional[int] = None) -> None:
        self.peer = peer  # InputPeer
        self.q = q  # string
        self.filter = filter  # MessagesFilter
        self.min_date = min_date  # int
        self.max_date = max_date  # int
        self.offset_id = offset_id  # int
        self.add_offset = add_offset  # int
        self.limit = limit  # int
        self.max_id = max_id  # int
        self.min_id = min_id  # int
        self.hash = hash  # long
        self.from_id = from_id  # flags.0?InputPeer
        self.saved_peer_id = saved_peer_id  # flags.2?InputPeer
        self.saved_reaction = saved_reaction  # flags.3?Vector<Reaction>
        self.top_msg_id = top_msg_id  # flags.1?int

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "Search":
        
        flags = Int.read(b)
        
        peer = TLObject.read(b)
        
        q = String.read(b)
        
        from_id = TLObject.read(b) if flags & (1 << 0) else None
        
        saved_peer_id = TLObject.read(b) if flags & (1 << 2) else None
        
        saved_reaction = TLObject.read(b) if flags & (1 << 3) else []
        
        top_msg_id = Int.read(b) if flags & (1 << 1) else None
        filter = TLObject.read(b)
        
        min_date = Int.read(b)
        
        max_date = Int.read(b)
        
        offset_id = Int.read(b)
        
        add_offset = Int.read(b)
        
        limit = Int.read(b)
        
        max_id = Int.read(b)
        
        min_id = Int.read(b)
        
        hash = Long.read(b)
        
        return Search(peer=peer, q=q, filter=filter, min_date=min_date, max_date=max_date, offset_id=offset_id, add_offset=add_offset, limit=limit, max_id=max_id, min_id=min_id, hash=hash, from_id=from_id, saved_peer_id=saved_peer_id, saved_reaction=saved_reaction, top_msg_id=top_msg_id)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.from_id is not None else 0
        flags |= (1 << 2) if self.saved_peer_id is not None else 0
        flags |= (1 << 3) if self.saved_reaction else 0
        flags |= (1 << 1) if self.top_msg_id is not None else 0
        b.write(Int(flags))
        
        b.write(self.peer.write())
        
        b.write(String(self.q))
        
        if self.from_id is not None:
            b.write(self.from_id.write())
        
        if self.saved_peer_id is not None:
            b.write(self.saved_peer_id.write())
        
        if self.saved_reaction is not None:
            b.write(Vector(self.saved_reaction))
        
        if self.top_msg_id is not None:
            b.write(Int(self.top_msg_id))
        
        b.write(self.filter.write())
        
        b.write(Int(self.min_date))
        
        b.write(Int(self.max_date))
        
        b.write(Int(self.offset_id))
        
        b.write(Int(self.add_offset))
        
        b.write(Int(self.limit))
        
        b.write(Int(self.max_id))
        
        b.write(Int(self.min_id))
        
        b.write(Long(self.hash))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

SendMessageAction = Union[raw.types.SendMessageCancelAction, raw.types.SendMessageChooseContactAction, raw.types.SendMessageChooseStickerAction, raw.types.SendMessageEmojiInteraction, raw.types.SendMessageEmojiInteractionSeen, raw.types.SendMessageGamePlayAction, raw.types.SendMessageGeoLocationAction, raw.types.SendMessageHistoryImportAction, raw.types.SendMessageRecordAudioAction, raw.types.SendMessageRecordRoundAction, raw.types.SendMessageRecordVideoAction, raw.types.SendMessageTypingAction, raw.types.SendMessageUploadAudioAction, raw.types.SendMessageUploadDocumentAction, raw.types.SendMessageUploadPhotoAction, raw.types.SendMessageUploadRoundAction, raw.types.SendMessageUploadVideoAction, raw.types.SpeakingInGroupCallAction]


# noinspection PyRedeclaration
class SendMessageAction:  # type: ignore
    """Telegram API base type.

    Constructors:
        This base type has 18 constructors available.

        .. currentmodule:: pyrogram.raw.types

        .. autosummary::
            :nosignatures:

            SendMessageCancelAction
            SendMessageChooseContactAction
            SendMessageChooseStickerAction
            SendMessageEmojiInteraction
            SendMessageEmojiInteractionSeen
            SendMessageGamePlayAction
            SendMessageGeoLocationAction
            SendMessageHistoryImportAction
            SendMessageRecordAudioAction
            SendMessageRecordRoundAction
            SendMessageRecordVideoAction
            SendMessageTypingAction
            SendMessageUploadAudioAction
            SendMessageUploadDocumentAction
            SendMessageUploadPhotoAction
            SendMessageUploadRoundAction
            SendMessageUploadVideoAction
            SpeakingInGroupCallAction
    """

    QUALNAME = "pyrogram.raw.base.SendMessageAction"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://pyrofork.mayuri.my.id/telegram/base/send-message-action")



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class PromoData(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.help.PromoData`.

    Details:
        - Layer: ``177``
        - ID: ``8C39793F``

    Parameters:
        expires (``int`` ``32-bit``):
            N/A

        peer (:obj:`Peer <pyrogram.raw.base.Peer>`):
            N/A

        chats (List of :obj:`Chat <pyrogram.raw.base.Chat>`):
            N/A

        users (List of :obj:`User <pyrogram.raw.base.User>`):
            N/A

        proxy (``bool``, *optional*):
            N/A

        psa_type (``str``, *optional*):
            N/A

        psa_message (``str``, *optional*):
            N/A

    Functions:
        This object can be returned by 1 function.

        .. currentmodule:: pyrogram.raw.functions

        .. autosummary::
            :nosignatures:

            help.GetPromoData
    """

    __slots__: List[str] = ["expires", "peer", "chats", "users", "proxy", "psa_type", "psa_message"]

    ID = 0x8c39793f
    QUALNAME = "types.help.PromoData"

    def __init__(self, *, expires: int, peer: "raw.base.Peer", chats: List["raw.base.Chat"], users: List["raw.base.User"], proxy: Optional[bool] = None, psa_type: Optional[str] = None, psa_message: Optional[str] = None) -> None:
        self.expires = expires  # int
        self.peer = peer  # Peer
        self.chats = chats  # Vector<Chat>
        self.users = users  # Vector<User>
        self.proxy = proxy  # flags.0?true
        self.psa_type = psa_type  # flags.1?string
        self.psa_message = psa_message  # flags.2?string

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "PromoData":
        
        flags = Int.read(b)
        
        proxy = True if flags & (1 << 0) else False
        expires = Int.read(b)
        
        peer = TLObject.read(b)
        
        chats = TLObject.read(b)
        
        users = TLObject.read(b)
        
        psa_type = String.read(b) if flags & (1 << 1) else None
        psa_message = String.read(b) if flags & (1 << 2) else None
        return PromoData(expires=expires, peer=peer, chats=chats, users=users, proxy=proxy, psa_type=psa_type, psa_message=psa_message)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.proxy else 0
        flags |= (1 << 1) if self.psa_type is not None else 0
        flags |= (1 << 2) if self.psa_message is not None else 0
        b.write(Int(flags))
        
        b.write(Int(self.expires))
        
        b.write(self.peer.write())
        
        b.write(Vector(self.chats))
        
        b.write(Vector(self.users))
        
        if self.psa_type is not None:
            b.write(String(self.psa_type))
        
        if self.psa_message is not None:
            b.write(String(self.psa_message))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class TopPeerCategoryPeers(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.TopPeerCategoryPeers`.

    Details:
        - Layer: ``177``
        - ID: ``FB834291``

    Parameters:
        category (:obj:`TopPeerCategory <pyrogram.raw.base.TopPeerCategory>`):
            N/A

        count (``int`` ``32-bit``):
            N/A

        peers (List of :obj:`TopPeer <pyrogram.raw.base.TopPeer>`):
            N/A

    """

    __slots__: List[str] = ["category", "count", "peers"]

    ID = 0xfb834291
    QUALNAME = "types.TopPeerCategoryPeers"

    def __init__(self, *, category: "raw.base.TopPeerCategory", count: int, peers: List["raw.base.TopPeer"]) -> None:
        self.category = category  # TopPeerCategory
        self.count = count  # int
        self.peers = peers  # Vector<TopPeer>

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "TopPeerCategoryPeers":
        # No flags
        
        category = TLObject.read(b)
        
        count = Int.read(b)
        
        peers = TLObject.read(b)
        
        return TopPeerCategoryPeers(category=category, count=count, peers=peers)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.category.write())
        
        b.write(Int(self.count))
        
        b.write(Vector(self.peers))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class InputPhoneContact(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.InputContact`.

    Details:
        - Layer: ``177``
        - ID: ``F392B7F4``

    Parameters:
        client_id (``int`` ``64-bit``):
            N/A

        phone (``str``):
            N/A

        first_name (``str``):
            N/A

        last_name (``str``):
            N/A

    """

    __slots__: List[str] = ["client_id", "phone", "first_name", "last_name"]

    ID = 0xf392b7f4
    QUALNAME = "types.InputPhoneContact"

    def __init__(self, *, client_id: int, phone: str, first_name: str, last_name: str) -> None:
        self.client_id = client_id  # long
        self.phone = phone  # string
        self.first_name = first_name  # string
        self.last_name = last_name  # string

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "InputPhoneContact":
        # No flags
        
        client_id = Long.read(b)
        
        phone = String.read(b)
        
        first_name = String.read(b)
        
        last_name = String.read(b)
        
        return InputPhoneContact(client_id=client_id, phone=phone, first_name=first_name, last_name=last_name)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(Long(self.client_id))
        
        b.write(String(self.phone))
        
        b.write(String(self.first_name))
        
        b.write(String(self.last_name))
        
        return b.getvalue()



#  Pyrogram - Telegram MTProto API Client Library for Python
#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from .advanced import Advanced
from .auth import Auth
from .bots import Bots
from .chats import Chats
from .contacts import Contacts
from .decorators import Decorators
from .invite_links import InviteLinks
from .messages import Messages
from .password import Password
from .pyromod import Pyromod
from .stickers import Stickers
from .users import Users
from .utilities import Utilities


class Methods(
    Advanced,
    Auth,
    Bots,
    Contacts,
    Password,
    Pyromod,
    Chats,
    Stickers,
    Users,
    Messages,
    Decorators,
    Utilities,
    InviteLinks,
):
    pass



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class RequestFirebaseSms(TLObject):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``177``
        - ID: ``89464B50``

    Parameters:
        phone_number (``str``):
            N/A

        phone_code_hash (``str``):
            N/A

        safety_net_token (``str``, *optional*):
            N/A

        ios_push_secret (``str``, *optional*):
            N/A

    Returns:
        ``bool``
    """

    __slots__: List[str] = ["phone_number", "phone_code_hash", "safety_net_token", "ios_push_secret"]

    ID = 0x89464b50
    QUALNAME = "functions.auth.RequestFirebaseSms"

    def __init__(self, *, phone_number: str, phone_code_hash: str, safety_net_token: Optional[str] = None, ios_push_secret: Optional[str] = None) -> None:
        self.phone_number = phone_number  # string
        self.phone_code_hash = phone_code_hash  # string
        self.safety_net_token = safety_net_token  # flags.0?string
        self.ios_push_secret = ios_push_secret  # flags.1?string

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "RequestFirebaseSms":
        
        flags = Int.read(b)
        
        phone_number = String.read(b)
        
        phone_code_hash = String.read(b)
        
        safety_net_token = String.read(b) if flags & (1 << 0) else None
        ios_push_secret = String.read(b) if flags & (1 << 1) else None
        return RequestFirebaseSms(phone_number=phone_number, phone_code_hash=phone_code_hash, safety_net_token=safety_net_token, ios_push_secret=ios_push_secret)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.safety_net_token is not None else 0
        flags |= (1 << 1) if self.ios_push_secret is not None else 0
        b.write(Int(flags))
        
        b.write(String(self.phone_number))
        
        b.write(String(self.phone_code_hash))
        
        if self.safety_net_token is not None:
            b.write(String(self.safety_net_token))
        
        if self.ios_push_secret is not None:
            b.write(String(self.ios_push_secret))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

import asyncio
import inspect
import pyrogram

from pyrogram.errors import ListenerTimeout
from pyrogram.filters import Filter
from typing import List, Optional, Union
from pyrogram.types import Identifier, Listener
from pyrogram.utils import PyromodConfig

class Listen:
    async def listen(
        self: "pyrogram.Client",
        filters: Optional[Filter] = None,
        listener_type: "pyrogram.enums.ListenerTypes" = pyrogram.enums.ListenerTypes.MESSAGE,
        timeout: Optional[int] = None,
        unallowed_click_alert: bool = True,
        chat_id: Union[Union[int, str], List[Union[int, str]]] = None,
        user_id: Union[Union[int, str], List[Union[int, str]]] = None,
        message_id: Union[int, List[int]] = None,
        inline_message_id: Union[str, List[str]] = None,
    ):
        """Listen for a message, callback query, etc.

        Message:

        .. include:: /_includes/usable-by/users-bots.rst

        CallbackQuery:

        .. include:: /_includes/usable-by/bots.rst

        Parameters:
            chat_id (``int`` | ``str`` | Iterable of ``int`` | Iterable of ``str``, *optional*):
                Unique identifier (int) or username (str) of the target chat.

            user_id (``int`` | ``str`` | Iterable of ``int`` | Iterable of ``str``, *optional*):
                The user ID to listen for.

            filters (:obj:`~pyrogram.filters`, *optional*):
                A filter to check the incoming message against.

            listener_type (:obj:`~pyrogram.enums.ListenerTypes`, *optional*):
                The type of listener to listen for.
                Default to Message.

            timeout (``int``, *optional*):
                The maximum amount of time to wait for a message.

            unallowed_click_alert (``bool``, *optional*):
                Whether to alert the user if they click a button that doesn’t match the filters.
                Default to True.

            message_id (``int``, *optional*):
                The message ID to listen for.

            inline_message_id (``str``, *optional*):
                The inline message ID to listen for.

        Returns:
            :obj:`~pyrogram.types.Message` | :obj:`~pyrogram.types.CallbackQuery`: On success, a message/callbackquery is returned.

        Example:
            .. code-block:: python

                await app.listen(chat_id)
        """

        pattern = Identifier(
            from_user_id=user_id,
            chat_id=chat_id,
            message_id=message_id,
            inline_message_id=inline_message_id,
        )

        loop = asyncio.get_event_loop()
        future = loop.create_future()

        listener = Listener(
            future=future,
            filters=filters,
            unallowed_click_alert=unallowed_click_alert,
            identifier=pattern,
            listener_type=listener_type,
        )

        future.add_done_callback(lambda _future: self.remove_listener(listener))

        self.listeners[listener_type].append(listener)

        try:
            return await asyncio.wait_for(future, timeout)
        except asyncio.exceptions.TimeoutError:
            if callable(PyromodConfig.timeout_handler):
                if inspect.iscoroutinefunction(PyromodConfig.timeout_handler.__call__):
                    await PyromodConfig.timeout_handler(pattern, listener, timeout)
                else:
                    await self.loop.run_in_executor(
                        None, PyromodConfig.timeout_handler, pattern, listener, timeout
                    )
            elif PyromodConfig.throw_exceptions:
                raise ListenerTimeout(timeout)



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class BotInlineMessageMediaVenue(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.BotInlineMessage`.

    Details:
        - Layer: ``177``
        - ID: ``8A86659C``

    Parameters:
        geo (:obj:`GeoPoint <pyrogram.raw.base.GeoPoint>`):
            N/A

        title (``str``):
            N/A

        address (``str``):
            N/A

        provider (``str``):
            N/A

        venue_id (``str``):
            N/A

        venue_type (``str``):
            N/A

        reply_markup (:obj:`ReplyMarkup <pyrogram.raw.base.ReplyMarkup>`, *optional*):
            N/A

    """

    __slots__: List[str] = ["geo", "title", "address", "provider", "venue_id", "venue_type", "reply_markup"]

    ID = 0x8a86659c
    QUALNAME = "types.BotInlineMessageMediaVenue"

    def __init__(self, *, geo: "raw.base.GeoPoint", title: str, address: str, provider: str, venue_id: str, venue_type: str, reply_markup: "raw.base.ReplyMarkup" = None) -> None:
        self.geo = geo  # GeoPoint
        self.title = title  # string
        self.address = address  # string
        self.provider = provider  # string
        self.venue_id = venue_id  # string
        self.venue_type = venue_type  # string
        self.reply_markup = reply_markup  # flags.2?ReplyMarkup

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "BotInlineMessageMediaVenue":
        
        flags = Int.read(b)
        
        geo = TLObject.read(b)
        
        title = String.read(b)
        
        address = String.read(b)
        
        provider = String.read(b)
        
        venue_id = String.read(b)
        
        venue_type = String.read(b)
        
        reply_markup = TLObject.read(b) if flags & (1 << 2) else None
        
        return BotInlineMessageMediaVenue(geo=geo, title=title, address=address, provider=provider, venue_id=venue_id, venue_type=venue_type, reply_markup=reply_markup)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 2) if self.reply_markup is not None else 0
        b.write(Int(flags))
        
        b.write(self.geo.write())
        
        b.write(String(self.title))
        
        b.write(String(self.address))
        
        b.write(String(self.provider))
        
        b.write(String(self.venue_id))
        
        b.write(String(self.venue_type))
        
        if self.reply_markup is not None:
            b.write(self.reply_markup.write())
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

import pyrogram
from pyrogram import raw


class AcceptTermsOfService:
    async def accept_terms_of_service(
        self: "pyrogram.Client",
        terms_of_service_id: str
    ) -> bool:
        """Accept the given terms of service.

        .. include:: /_includes/usable-by/users.rst

        Parameters:
            terms_of_service_id (``str``):
                The terms of service identifier.
        """
        r = await self.invoke(
            raw.functions.help.AcceptTermsOfService(
                id=raw.types.DataJSON(
                    data=terms_of_service_id
                )
            )
        )

        return bool(r)



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class Authorization(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.Authorization`.

    Details:
        - Layer: ``177``
        - ID: ``AD01D61D``

    Parameters:
        hash (``int`` ``64-bit``):
            N/A

        device_model (``str``):
            N/A

        platform (``str``):
            N/A

        system_version (``str``):
            N/A

        api_id (``int`` ``32-bit``):
            N/A

        app_name (``str``):
            N/A

        app_version (``str``):
            N/A

        date_created (``int`` ``32-bit``):
            N/A

        date_active (``int`` ``32-bit``):
            N/A

        ip (``str``):
            N/A

        country (``str``):
            N/A

        region (``str``):
            N/A

        current (``bool``, *optional*):
            N/A

        official_app (``bool``, *optional*):
            N/A

        password_pending (``bool``, *optional*):
            N/A

        encrypted_requests_disabled (``bool``, *optional*):
            N/A

        call_requests_disabled (``bool``, *optional*):
            N/A

        unconfirmed (``bool``, *optional*):
            N/A

    Functions:
        This object can be returned by 1 function.

        .. currentmodule:: pyrogram.raw.functions

        .. autosummary::
            :nosignatures:

            auth.AcceptLoginToken
    """

    __slots__: List[str] = ["hash", "device_model", "platform", "system_version", "api_id", "app_name", "app_version", "date_created", "date_active", "ip", "country", "region", "current", "official_app", "password_pending", "encrypted_requests_disabled", "call_requests_disabled", "unconfirmed"]

    ID = 0xad01d61d
    QUALNAME = "types.Authorization"

    def __init__(self, *, hash: int, device_model: str, platform: str, system_version: str, api_id: int, app_name: str, app_version: str, date_created: int, date_active: int, ip: str, country: str, region: str, current: Optional[bool] = None, official_app: Optional[bool] = None, password_pending: Optional[bool] = None, encrypted_requests_disabled: Optional[bool] = None, call_requests_disabled: Optional[bool] = None, unconfirmed: Optional[bool] = None) -> None:
        self.hash = hash  # long
        self.device_model = device_model  # string
        self.platform = platform  # string
        self.system_version = system_version  # string
        self.api_id = api_id  # int
        self.app_name = app_name  # string
        self.app_version = app_version  # string
        self.date_created = date_created  # int
        self.date_active = date_active  # int
        self.ip = ip  # string
        self.country = country  # string
        self.region = region  # string
        self.current = current  # flags.0?true
        self.official_app = official_app  # flags.1?true
        self.password_pending = password_pending  # flags.2?true
        self.encrypted_requests_disabled = encrypted_requests_disabled  # flags.3?true
        self.call_requests_disabled = call_requests_disabled  # flags.4?true
        self.unconfirmed = unconfirmed  # flags.5?true

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "Authorization":
        
        flags = Int.read(b)
        
        current = True if flags & (1 << 0) else False
        official_app = True if flags & (1 << 1) else False
        password_pending = True if flags & (1 << 2) else False
        encrypted_requests_disabled = True if flags & (1 << 3) else False
        call_requests_disabled = True if flags & (1 << 4) else False
        unconfirmed = True if flags & (1 << 5) else False
        hash = Long.read(b)
        
        device_model = String.read(b)
        
        platform = String.read(b)
        
        system_version = String.read(b)
        
        api_id = Int.read(b)
        
        app_name = String.read(b)
        
        app_version = String.read(b)
        
        date_created = Int.read(b)
        
        date_active = Int.read(b)
        
        ip = String.read(b)
        
        country = String.read(b)
        
        region = String.read(b)
        
        return Authorization(hash=hash, device_model=device_model, platform=platform, system_version=system_version, api_id=api_id, app_name=app_name, app_version=app_version, date_created=date_created, date_active=date_active, ip=ip, country=country, region=region, current=current, official_app=official_app, password_pending=password_pending, encrypted_requests_disabled=encrypted_requests_disabled, call_requests_disabled=call_requests_disabled, unconfirmed=unconfirmed)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.current else 0
        flags |= (1 << 1) if self.official_app else 0
        flags |= (1 << 2) if self.password_pending else 0
        flags |= (1 << 3) if self.encrypted_requests_disabled else 0
        flags |= (1 << 4) if self.call_requests_disabled else 0
        flags |= (1 << 5) if self.unconfirmed else 0
        b.write(Int(flags))
        
        b.write(Long(self.hash))
        
        b.write(String(self.device_model))
        
        b.write(String(self.platform))
        
        b.write(String(self.system_version))
        
        b.write(Int(self.api_id))
        
        b.write(String(self.app_name))
        
        b.write(String(self.app_version))
        
        b.write(Int(self.date_created))
        
        b.write(Int(self.date_active))
        
        b.write(String(self.ip))
        
        b.write(String(self.country))
        
        b.write(String(self.region))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from .res_pq import ResPQ
from .pq_inner_data import PQInnerData
from .pq_inner_data_dc import PQInnerDataDc
from .pq_inner_data_temp import PQInnerDataTemp
from .pq_inner_data_temp_dc import PQInnerDataTempDc
from .bind_auth_key_inner import BindAuthKeyInner
from .server_dh_params_fail import ServerDHParamsFail
from .server_dh_params_ok import ServerDHParamsOk
from .server_dh_inner_data import ServerDHInnerData
from .client_dh_inner_data import ClientDHInnerData
from .dh_gen_ok import DhGenOk
from .dh_gen_retry import DhGenRetry
from .dh_gen_fail import DhGenFail
from .destroy_auth_key_ok import DestroyAuthKeyOk
from .destroy_auth_key_none import DestroyAuthKeyNone
from .destroy_auth_key_fail import DestroyAuthKeyFail
from .msgs_ack import MsgsAck
from .bad_msg_notification import BadMsgNotification
from .bad_server_salt import BadServerSalt
from .msgs_state_req import MsgsStateReq
from .msgs_state_info import MsgsStateInfo
from .msgs_all_info import MsgsAllInfo
from .msg_detailed_info import MsgDetailedInfo
from .msg_new_detailed_info import MsgNewDetailedInfo
from .msg_resend_req import MsgResendReq
from .msg_resend_ans_req import MsgResendAnsReq
from .rpc_result import RpcResult
from .rpc_error import RpcError
from .rpc_answer_unknown import RpcAnswerUnknown
from .rpc_answer_dropped_running import RpcAnswerDroppedRunning
from .rpc_answer_dropped import RpcAnswerDropped
from .pong import Pong
from .destroy_session_ok import DestroySessionOk
from .destroy_session_none import DestroySessionNone
from .new_session_created import NewSessionCreated
from .http_wait import HttpWait
from .ip_port import IpPort
from .ip_port_secret import IpPortSecret
from .access_point_rule import AccessPointRule
from .input_peer_empty import InputPeerEmpty
from .input_peer_self import InputPeerSelf
from .input_peer_chat import InputPeerChat
from .input_peer_user import InputPeerUser
from .input_peer_channel import InputPeerChannel
from .input_peer_user_from_message import InputPeerUserFromMessage
from .input_peer_channel_from_message import InputPeerChannelFromMessage
from .input_user_empty import InputUserEmpty
from .input_user_self import InputUserSelf
from .input_user import InputUser
from .input_user_from_message import InputUserFromMessage
from .input_phone_contact import InputPhoneContact
from .input_file import InputFile
from .input_file_big import InputFileBig
from .input_media_empty import InputMediaEmpty
from .input_media_uploaded_photo import InputMediaUploadedPhoto
from .input_media_photo import InputMediaPhoto
from .input_media_geo_point import InputMediaGeoPoint
from .input_media_contact import InputMediaContact
from .input_media_uploaded_document import InputMediaUploadedDocument
from .input_media_document import InputMediaDocument
from .input_media_venue import InputMediaVenue
from .input_media_photo_external import InputMediaPhotoExternal
from .input_media_document_external import InputMediaDocumentExternal
from .input_media_game import InputMediaGame
from .input_media_invoice import InputMediaInvoice
from .input_media_geo_live import InputMediaGeoLive
from .input_media_poll import InputMediaPoll
from .input_media_dice import InputMediaDice
from .input_media_story import InputMediaStory
from .input_media_web_page import InputMediaWebPage
from .input_chat_photo_empty import InputChatPhotoEmpty
from .input_chat_uploaded_photo import InputChatUploadedPhoto
from .input_chat_photo import InputChatPhoto
from .input_geo_point_empty import InputGeoPointEmpty
from .input_geo_point import InputGeoPoint
from .input_photo_empty import InputPhotoEmpty
from .input_photo import InputPhoto
from .input_file_location import InputFileLocation
from .input_encrypted_file_location import InputEncryptedFileLocation
from .input_document_file_location import InputDocumentFileLocation
from .input_secure_file_location import InputSecureFileLocation
from .input_takeout_file_location import InputTakeoutFileLocation
from .input_photo_file_location import InputPhotoFileLocation
from .input_photo_legacy_file_location import InputPhotoLegacyFileLocation
from .input_peer_photo_file_location import InputPeerPhotoFileLocation
from .input_sticker_set_thumb import InputStickerSetThumb
from .input_group_call_stream import InputGroupCallStream
from .peer_user import PeerUser
from .peer_chat import PeerChat
from .peer_channel import PeerChannel
from .user_empty import UserEmpty
from .user import User
from .user_profile_photo_empty import UserProfilePhotoEmpty
from .user_profile_photo import UserProfilePhoto
from .user_status_empty import UserStatusEmpty
from .user_status_online import UserStatusOnline
from .user_status_offline import UserStatusOffline
from .user_status_recently import UserStatusRecently
from .user_status_last_week import UserStatusLastWeek
from .user_status_last_month import UserStatusLastMonth
from .chat_empty import ChatEmpty
from .chat import Chat
from .chat_forbidden import ChatForbidden
from .channel import Channel
from .channel_forbidden import ChannelForbidden
from .chat_full import ChatFull
from .channel_full import ChannelFull
from .chat_participant import ChatParticipant
from .chat_participant_creator import ChatParticipantCreator
from .chat_participant_admin import ChatParticipantAdmin
from .chat_participants_forbidden import ChatParticipantsForbidden
from .chat_participants import ChatParticipants
from .chat_photo_empty import ChatPhotoEmpty
from .chat_photo import ChatPhoto
from .message_empty import MessageEmpty
from .message import Message
from .message_service import MessageService
from .message_media_empty import MessageMediaEmpty
from .message_media_photo import MessageMediaPhoto
from .message_media_geo import MessageMediaGeo
from .message_media_contact import MessageMediaContact
from .message_media_unsupported import MessageMediaUnsupported
from .message_media_document import MessageMediaDocument
from .message_media_web_page import MessageMediaWebPage
from .message_media_venue import MessageMediaVenue
from .message_media_game import MessageMediaGame
from .message_media_invoice import MessageMediaInvoice
from .message_media_geo_live import MessageMediaGeoLive
from .message_media_poll import MessageMediaPoll
from .message_media_dice import MessageMediaDice
from .message_media_story import MessageMediaStory
from .message_media_giveaway import MessageMediaGiveaway
from .message_media_giveaway_results import MessageMediaGiveawayResults
from .message_action_empty import MessageActionEmpty
from .message_action_chat_create import MessageActionChatCreate
from .message_action_chat_edit_title import MessageActionChatEditTitle
from .message_action_chat_edit_photo import MessageActionChatEditPhoto
from .message_action_chat_delete_photo import MessageActionChatDeletePhoto
from .message_action_chat_add_user import MessageActionChatAddUser
from .message_action_chat_delete_user import MessageActionChatDeleteUser
from .message_action_chat_joined_by_link import MessageActionChatJoinedByLink
from .message_action_channel_create import MessageActionChannelCreate
from .message_action_chat_migrate_to import MessageActionChatMigrateTo
from .message_action_channel_migrate_from import MessageActionChannelMigrateFrom
from .message_action_pin_message import MessageActionPinMessage
from .message_action_history_clear import MessageActionHistoryClear
from .message_action_game_score import MessageActionGameScore
from .message_action_payment_sent_me import MessageActionPaymentSentMe
from .message_action_payment_sent import MessageActionPaymentSent
from .message_action_phone_call import MessageActionPhoneCall
from .message_action_screenshot_taken import MessageActionScreenshotTaken
from .message_action_custom_action import MessageActionCustomAction
from .message_action_bot_allowed import MessageActionBotAllowed
from .message_action_secure_values_sent_me import MessageActionSecureValuesSentMe
from .message_action_secure_values_sent import MessageActionSecureValuesSent
from .message_action_contact_sign_up import MessageActionContactSignUp
from .message_action_geo_proximity_reached import MessageActionGeoProximityReached
from .message_action_group_call import MessageActionGroupCall
from .message_action_invite_to_group_call import MessageActionInviteToGroupCall
from .message_action_set_messages_ttl import MessageActionSetMessagesTTL
from .message_action_group_call_scheduled import MessageActionGroupCallScheduled
from .message_action_set_chat_theme import MessageActionSetChatTheme
from .message_action_chat_joined_by_request import MessageActionChatJoinedByRequest
from .message_action_web_view_data_sent_me import MessageActionWebViewDataSentMe
from .message_action_web_view_data_sent import MessageActionWebViewDataSent
from .message_action_gift_premium import MessageActionGiftPremium
from .message_action_topic_create import MessageActionTopicCreate
from .message_action_topic_edit import MessageActionTopicEdit
from .message_action_suggest_profile_photo import MessageActionSuggestProfilePhoto
from .message_action_requested_peer import MessageActionRequestedPeer
from .message_action_set_chat_wall_paper import MessageActionSetChatWallPaper
from .message_action_gift_code import MessageActionGiftCode
from .message_action_giveaway_launch import MessageActionGiveawayLaunch
from .message_action_giveaway_results import MessageActionGiveawayResults
from .message_action_boost_apply import MessageActionBoostApply
from .message_action_requested_peer_sent_me import MessageActionRequestedPeerSentMe
from .dialog import Dialog
from .dialog_folder import DialogFolder
from .photo_empty import PhotoEmpty
from .photo import Photo
from .photo_size_empty import PhotoSizeEmpty
from .photo_size import PhotoSize
from .photo_cached_size import PhotoCachedSize
from .photo_stripped_size import PhotoStrippedSize
from .photo_size_progressive import PhotoSizeProgressive
from .photo_path_size import PhotoPathSize
from .geo_point_empty import GeoPointEmpty
from .geo_point import GeoPoint
from .input_notify_peer import InputNotifyPeer
from .input_notify_users import InputNotifyUsers
from .input_notify_chats import InputNotifyChats
from .input_notify_broadcasts import InputNotifyBroadcasts
from .input_notify_forum_topic import InputNotifyForumTopic
from .input_peer_notify_settings import InputPeerNotifySettings
from .peer_notify_settings import PeerNotifySettings
from .peer_settings import PeerSettings
from .wall_paper import WallPaper
from .wall_paper_no_file import WallPaperNoFile
from .input_report_reason_spam import InputReportReasonSpam
from .input_report_reason_violence import InputReportReasonViolence
from .input_report_reason_pornography import InputReportReasonPornography
from .input_report_reason_child_abuse import InputReportReasonChildAbuse
from .input_report_reason_other import InputReportReasonOther
from .input_report_reason_copyright import InputReportReasonCopyright
from .input_report_reason_geo_irrelevant import InputReportReasonGeoIrrelevant
from .input_report_reason_fake import InputReportReasonFake
from .input_report_reason_illegal_drugs import InputReportReasonIllegalDrugs
from .input_report_reason_personal_details import InputReportReasonPersonalDetails
from .user_full import UserFull
from .contact import Contact
from .imported_contact import ImportedContact
from .contact_status import ContactStatus
from .input_messages_filter_empty import InputMessagesFilterEmpty
from .input_messages_filter_photos import InputMessagesFilterPhotos
from .input_messages_filter_video import InputMessagesFilterVideo
from .input_messages_filter_photo_video import InputMessagesFilterPhotoVideo
from .input_messages_filter_document import InputMessagesFilterDocument
from .input_messages_filter_url import InputMessagesFilterUrl
from .input_messages_filter_gif import InputMessagesFilterGif
from .input_messages_filter_voice import InputMessagesFilterVoice
from .input_messages_filter_music import InputMessagesFilterMusic
from .input_messages_filter_chat_photos import InputMessagesFilterChatPhotos
from .input_messages_filter_phone_calls import InputMessagesFilterPhoneCalls
from .input_messages_filter_round_voice import InputMessagesFilterRoundVoice
from .input_messages_filter_round_video import InputMessagesFilterRoundVideo
from .input_messages_filter_my_mentions import InputMessagesFilterMyMentions
from .input_messages_filter_geo import InputMessagesFilterGeo
from .input_messages_filter_contacts import InputMessagesFilterContacts
from .input_messages_filter_pinned import InputMessagesFilterPinned
from .update_new_message import UpdateNewMessage
from .update_message_id import UpdateMessageID
from .update_delete_messages import UpdateDeleteMessages
from .update_user_typing import UpdateUserTyping
from .update_chat_user_typing import UpdateChatUserTyping
from .update_chat_participants import UpdateChatParticipants
from .update_user_status import UpdateUserStatus
from .update_user_name import UpdateUserName
from .update_new_authorization import UpdateNewAuthorization
from .update_new_encrypted_message import UpdateNewEncryptedMessage
from .update_encrypted_chat_typing import UpdateEncryptedChatTyping
from .update_encryption import UpdateEncryption
from .update_encrypted_messages_read import UpdateEncryptedMessagesRead
from .update_chat_participant_add import UpdateChatParticipantAdd
from .update_chat_participant_delete import UpdateChatParticipantDelete
from .update_dc_options import UpdateDcOptions
from .update_notify_settings import UpdateNotifySettings
from .update_service_notification import UpdateServiceNotification
from .update_privacy import UpdatePrivacy
from .update_user_phone import UpdateUserPhone
from .update_read_history_inbox import UpdateReadHistoryInbox
from .update_read_history_outbox import UpdateReadHistoryOutbox
from .update_web_page import UpdateWebPage
from .update_read_messages_contents import UpdateReadMessagesContents
from .update_channel_too_long import UpdateChannelTooLong
from .update_channel import UpdateChannel
from .update_new_channel_message import UpdateNewChannelMessage
from .update_read_channel_inbox import UpdateReadChannelInbox
from .update_delete_channel_messages import UpdateDeleteChannelMessages
from .update_channel_message_views import UpdateChannelMessageViews
from .update_chat_participant_admin import UpdateChatParticipantAdmin
from .update_new_sticker_set import UpdateNewStickerSet
from .update_sticker_sets_order import UpdateStickerSetsOrder
from .update_sticker_sets import UpdateStickerSets
from .update_saved_gifs import UpdateSavedGifs
from .update_bot_inline_query import UpdateBotInlineQuery
from .update_bot_inline_send import UpdateBotInlineSend
from .update_edit_channel_message import UpdateEditChannelMessage
from .update_bot_callback_query import UpdateBotCallbackQuery
from .update_edit_message import UpdateEditMessage
from .update_inline_bot_callback_query import UpdateInlineBotCallbackQuery
from .update_read_channel_outbox import UpdateReadChannelOutbox
from .update_draft_message import UpdateDraftMessage
from .update_read_featured_stickers import UpdateReadFeaturedStickers
from .update_recent_stickers import UpdateRecentStickers
from .update_config import UpdateConfig
from .update_pts_changed import UpdatePtsChanged
from .update_channel_web_page import UpdateChannelWebPage
from .update_dialog_pinned import UpdateDialogPinned
from .update_pinned_dialogs import UpdatePinnedDialogs
from .update_bot_webhook_json import UpdateBotWebhookJSON
from .update_bot_webhook_json_query import UpdateBotWebhookJSONQuery
from .update_bot_shipping_query import UpdateBotShippingQuery
from .update_bot_precheckout_query import UpdateBotPrecheckoutQuery
from .update_phone_call import UpdatePhoneCall
from .update_lang_pack_too_long import UpdateLangPackTooLong
from .update_lang_pack import UpdateLangPack
from .update_faved_stickers import UpdateFavedStickers
from .update_channel_read_messages_contents import UpdateChannelReadMessagesContents
from .update_contacts_reset import UpdateContactsReset
from .update_channel_available_messages import UpdateChannelAvailableMessages
from .update_dialog_unread_mark import UpdateDialogUnreadMark
from .update_message_poll import UpdateMessagePoll
from .update_chat_default_banned_rights import UpdateChatDefaultBannedRights
from .update_folder_peers import UpdateFolderPeers
from .update_peer_settings import UpdatePeerSettings
from .update_peer_located import UpdatePeerLocated
from .update_new_scheduled_message import UpdateNewScheduledMessage
from .update_delete_scheduled_messages import UpdateDeleteScheduledMessages
from .update_theme import UpdateTheme
from .update_geo_live_viewed import UpdateGeoLiveViewed
from .update_login_token import UpdateLoginToken
from .update_message_poll_vote import UpdateMessagePollVote
from .update_dialog_filter import UpdateDialogFilter
from .update_dialog_filter_order import UpdateDialogFilterOrder
from .update_dialog_filters import UpdateDialogFilters
from .update_phone_call_signaling_data import UpdatePhoneCallSignalingData
from .update_channel_message_forwards import UpdateChannelMessageForwards
from .update_read_channel_discussion_inbox import UpdateReadChannelDiscussionInbox
from .update_read_channel_discussion_outbox import UpdateReadChannelDiscussionOutbox
from .update_peer_blocked import UpdatePeerBlocked
from .update_channel_user_typing import UpdateChannelUserTyping
from .update_pinned_messages import UpdatePinnedMessages
from .update_pinned_channel_messages import UpdatePinnedChannelMessages
from .update_chat import UpdateChat
from .update_group_call_participants import UpdateGroupCallParticipants
from .update_group_call import UpdateGroupCall
from .update_peer_history_ttl import UpdatePeerHistoryTTL
from .update_chat_participant import UpdateChatParticipant
from .update_channel_participant import UpdateChannelParticipant
from .update_bot_stopped import UpdateBotStopped
from .update_group_call_connection import UpdateGroupCallConnection
from .update_bot_commands import UpdateBotCommands
from .update_pending_join_requests import UpdatePendingJoinRequests
from .update_bot_chat_invite_requester import UpdateBotChatInviteRequester
from .update_message_reactions import UpdateMessageReactions
from .update_attach_menu_bots import UpdateAttachMenuBots
from .update_web_view_result_sent import UpdateWebViewResultSent
from .update_bot_menu_button import UpdateBotMenuButton
from .update_saved_ringtones import UpdateSavedRingtones
from .update_transcribed_audio import UpdateTranscribedAudio
from .update_read_featured_emoji_stickers import UpdateReadFeaturedEmojiStickers
from .update_user_emoji_status import UpdateUserEmojiStatus
from .update_recent_emoji_statuses import UpdateRecentEmojiStatuses
from .update_recent_reactions import UpdateRecentReactions
from .update_move_sticker_set_to_top import UpdateMoveStickerSetToTop
from .update_message_extended_media import UpdateMessageExtendedMedia
from .update_channel_pinned_topic import UpdateChannelPinnedTopic
from .update_channel_pinned_topics import UpdateChannelPinnedTopics
from .update_user import UpdateUser
from .update_auto_save_settings import UpdateAutoSaveSettings
from .update_story import UpdateStory
from .update_read_stories import UpdateReadStories
from .update_story_id import UpdateStoryID
from .update_stories_stealth_mode import UpdateStoriesStealthMode
from .update_sent_story_reaction import UpdateSentStoryReaction
from .update_bot_chat_boost import UpdateBotChatBoost
from .update_channel_view_forum_as_messages import UpdateChannelViewForumAsMessages
from .update_peer_wallpaper import UpdatePeerWallpaper
from .update_bot_message_reaction import UpdateBotMessageReaction
from .update_bot_message_reactions import UpdateBotMessageReactions
from .update_saved_dialog_pinned import UpdateSavedDialogPinned
from .update_pinned_saved_dialogs import UpdatePinnedSavedDialogs
from .update_saved_reaction_tags import UpdateSavedReactionTags
from .update_sms_job import UpdateSmsJob
from .update_quick_replies import UpdateQuickReplies
from .update_new_quick_reply import UpdateNewQuickReply
from .update_delete_quick_reply import UpdateDeleteQuickReply
from .update_quick_reply_message import UpdateQuickReplyMessage
from .update_delete_quick_reply_messages import UpdateDeleteQuickReplyMessages
from .update_bot_business_connect import UpdateBotBusinessConnect
from .update_bot_new_business_message import UpdateBotNewBusinessMessage
from .update_bot_edit_business_message import UpdateBotEditBusinessMessage
from .update_bot_delete_business_message import UpdateBotDeleteBusinessMessage
from .updates_too_long import UpdatesTooLong
from .update_short_message import UpdateShortMessage
from .update_short_chat_message import UpdateShortChatMessage
from .update_short import UpdateShort
from .updates_combined import UpdatesCombined
from .updates_t import Updates
from .update_short_sent_message import UpdateShortSentMessage
from .dc_option import DcOption
from .config import Config
from .nearest_dc import NearestDc
from .encrypted_chat_empty import EncryptedChatEmpty
from .encrypted_chat_waiting import EncryptedChatWaiting
from .encrypted_chat_requested import EncryptedChatRequested
from .encrypted_chat import EncryptedChat
from .encrypted_chat_discarded import EncryptedChatDiscarded
from .input_encrypted_chat import InputEncryptedChat
from .encrypted_file_empty import EncryptedFileEmpty
from .encrypted_file import EncryptedFile
from .input_encrypted_file_empty import InputEncryptedFileEmpty
from .input_encrypted_file_uploaded import InputEncryptedFileUploaded
from .input_encrypted_file import InputEncryptedFile
from .input_encrypted_file_big_uploaded import InputEncryptedFileBigUploaded
from .encrypted_message import EncryptedMessage
from .encrypted_message_service import EncryptedMessageService
from .input_document_empty import InputDocumentEmpty
from .input_document import InputDocument
from .document_empty import DocumentEmpty
from .document import Document
from .notify_peer import NotifyPeer
from .notify_users import NotifyUsers
from .notify_chats import NotifyChats
from .notify_broadcasts import NotifyBroadcasts
from .notify_forum_topic import NotifyForumTopic
from .send_message_typing_action import SendMessageTypingAction
from .send_message_cancel_action import SendMessageCancelAction
from .send_message_record_video_action import SendMessageRecordVideoAction
from .send_message_upload_video_action import SendMessageUploadVideoAction
from .send_message_record_audio_action import SendMessageRecordAudioAction
from .send_message_upload_audio_action import SendMessageUploadAudioAction
from .send_message_upload_photo_action import SendMessageUploadPhotoAction
from .send_message_upload_document_action import SendMessageUploadDocumentAction
from .send_message_geo_location_action import SendMessageGeoLocationAction
from .send_message_choose_contact_action import SendMessageChooseContactAction
from .send_message_game_play_action import SendMessageGamePlayAction
from .send_message_record_round_action import SendMessageRecordRoundAction
from .send_message_upload_round_action import SendMessageUploadRoundAction
from .speaking_in_group_call_action import SpeakingInGroupCallAction
from .send_message_history_import_action import SendMessageHistoryImportAction
from .send_message_choose_sticker_action import SendMessageChooseStickerAction
from .send_message_emoji_interaction import SendMessageEmojiInteraction
from .send_message_emoji_interaction_seen import SendMessageEmojiInteractionSeen
from .input_privacy_key_status_timestamp import InputPrivacyKeyStatusTimestamp
from .input_privacy_key_chat_invite import InputPrivacyKeyChatInvite
from .input_privacy_key_phone_call import InputPrivacyKeyPhoneCall
from .input_privacy_key_phone_p2_p import InputPrivacyKeyPhoneP2P
from .input_privacy_key_forwards import InputPrivacyKeyForwards
from .input_privacy_key_profile_photo import InputPrivacyKeyProfilePhoto
from .input_privacy_key_phone_number import InputPrivacyKeyPhoneNumber
from .input_privacy_key_added_by_phone import InputPrivacyKeyAddedByPhone
from .input_privacy_key_voice_messages import InputPrivacyKeyVoiceMessages
from .input_privacy_key_about import InputPrivacyKeyAbout
from .input_privacy_key_birthday import InputPrivacyKeyBirthday
from .privacy_key_status_timestamp import PrivacyKeyStatusTimestamp
from .privacy_key_chat_invite import PrivacyKeyChatInvite
from .privacy_key_phone_call import PrivacyKeyPhoneCall
from .privacy_key_phone_p2_p import PrivacyKeyPhoneP2P
from .privacy_key_forwards import PrivacyKeyForwards
from .privacy_key_profile_photo import PrivacyKeyProfilePhoto
from .privacy_key_phone_number import PrivacyKeyPhoneNumber
from .privacy_key_added_by_phone import PrivacyKeyAddedByPhone
from .privacy_key_voice_messages import PrivacyKeyVoiceMessages
from .privacy_key_about import PrivacyKeyAbout
from .privacy_key_birthday import PrivacyKeyBirthday
from .input_privacy_value_allow_contacts import InputPrivacyValueAllowContacts
from .input_privacy_value_allow_all import InputPrivacyValueAllowAll
from .input_privacy_value_allow_users import InputPrivacyValueAllowUsers
from .input_privacy_value_disallow_contacts import InputPrivacyValueDisallowContacts
from .input_privacy_value_disallow_all import InputPrivacyValueDisallowAll
from .input_privacy_value_disallow_users import InputPrivacyValueDisallowUsers
from .input_privacy_value_allow_chat_participants import InputPrivacyValueAllowChatParticipants
from .input_privacy_value_disallow_chat_participants import InputPrivacyValueDisallowChatParticipants
from .input_privacy_value_allow_close_friends import InputPrivacyValueAllowCloseFriends
from .input_privacy_value_allow_premium import InputPrivacyValueAllowPremium
from .privacy_value_allow_contacts import PrivacyValueAllowContacts
from .privacy_value_allow_all import PrivacyValueAllowAll
from .privacy_value_allow_users import PrivacyValueAllowUsers
from .privacy_value_disallow_contacts import PrivacyValueDisallowContacts
from .privacy_value_disallow_all import PrivacyValueDisallowAll
from .privacy_value_disallow_users import PrivacyValueDisallowUsers
from .privacy_value_allow_chat_participants import PrivacyValueAllowChatParticipants
from .privacy_value_disallow_chat_participants import PrivacyValueDisallowChatParticipants
from .privacy_value_allow_close_friends import PrivacyValueAllowCloseFriends
from .privacy_value_allow_premium import PrivacyValueAllowPremium
from .account_days_ttl import AccountDaysTTL
from .document_attribute_image_size import DocumentAttributeImageSize
from .document_attribute_animated import DocumentAttributeAnimated
from .document_attribute_sticker import DocumentAttributeSticker
from .document_attribute_video import DocumentAttributeVideo
from .document_attribute_audio import DocumentAttributeAudio
from .document_attribute_filename import DocumentAttributeFilename
from .document_attribute_has_stickers import DocumentAttributeHasStickers
from .document_attribute_custom_emoji import DocumentAttributeCustomEmoji
from .sticker_pack import StickerPack
from .web_page_empty import WebPageEmpty
from .web_page_pending import WebPagePending
from .web_page import WebPage
from .web_page_not_modified import WebPageNotModified
from .authorization import Authorization
from .received_notify_message import ReceivedNotifyMessage
from .chat_invite_exported import ChatInviteExported
from .chat_invite_public_join_requests import ChatInvitePublicJoinRequests
from .chat_invite_already import ChatInviteAlready
from .chat_invite import ChatInvite
from .chat_invite_peek import ChatInvitePeek
from .input_sticker_set_empty import InputStickerSetEmpty
from .input_sticker_set_id import InputStickerSetID
from .input_sticker_set_short_name import InputStickerSetShortName
from .input_sticker_set_animated_emoji import InputStickerSetAnimatedEmoji
from .input_sticker_set_dice import InputStickerSetDice
from .input_sticker_set_animated_emoji_animations import InputStickerSetAnimatedEmojiAnimations
from .input_sticker_set_premium_gifts import InputStickerSetPremiumGifts
from .input_sticker_set_emoji_generic_animations import InputStickerSetEmojiGenericAnimations
from .input_sticker_set_emoji_default_statuses import InputStickerSetEmojiDefaultStatuses
from .input_sticker_set_emoji_default_topic_icons import InputStickerSetEmojiDefaultTopicIcons
from .input_sticker_set_emoji_channel_default_statuses import InputStickerSetEmojiChannelDefaultStatuses
from .sticker_set import StickerSet
from .bot_command import BotCommand
from .bot_info import BotInfo
from .keyboard_button import KeyboardButton
from .keyboard_button_url import KeyboardButtonUrl
from .keyboard_button_callback import KeyboardButtonCallback
from .keyboard_button_request_phone import KeyboardButtonRequestPhone
from .keyboard_button_request_geo_location import KeyboardButtonRequestGeoLocation
from .keyboard_button_switch_inline import KeyboardButtonSwitchInline
from .keyboard_button_game import KeyboardButtonGame
from .keyboard_button_buy import KeyboardButtonBuy
from .keyboard_button_url_auth import KeyboardButtonUrlAuth
from .input_keyboard_button_url_auth import InputKeyboardButtonUrlAuth
from .keyboard_button_request_poll import KeyboardButtonRequestPoll
from .input_keyboard_button_user_profile import InputKeyboardButtonUserProfile
from .keyboard_button_user_profile import KeyboardButtonUserProfile
from .keyboard_button_web_view import KeyboardButtonWebView
from .keyboard_button_simple_web_view import KeyboardButtonSimpleWebView
from .keyboard_button_request_peer import KeyboardButtonRequestPeer
from .input_keyboard_button_request_peer import InputKeyboardButtonRequestPeer
from .keyboard_button_row import KeyboardButtonRow
from .reply_keyboard_hide import ReplyKeyboardHide
from .reply_keyboard_force_reply import ReplyKeyboardForceReply
from .reply_keyboard_markup import ReplyKeyboardMarkup
from .reply_inline_markup import ReplyInlineMarkup
from .message_entity_unknown import MessageEntityUnknown
from .message_entity_mention import MessageEntityMention
from .message_entity_hashtag import MessageEntityHashtag
from .message_entity_bot_command import MessageEntityBotCommand
from .message_entity_url import MessageEntityUrl
from .message_entity_email import MessageEntityEmail
from .message_entity_bold import MessageEntityBold
from .message_entity_italic import MessageEntityItalic
from .message_entity_code import MessageEntityCode
from .message_entity_pre import MessageEntityPre
from .message_entity_text_url import MessageEntityTextUrl
from .message_entity_mention_name import MessageEntityMentionName
from .input_message_entity_mention_name import InputMessageEntityMentionName
from .message_entity_phone import MessageEntityPhone
from .message_entity_cashtag import MessageEntityCashtag
from .message_entity_underline import MessageEntityUnderline
from .message_entity_strike import MessageEntityStrike
from .message_entity_bank_card import MessageEntityBankCard
from .message_entity_spoiler import MessageEntitySpoiler
from .message_entity_custom_emoji import MessageEntityCustomEmoji
from .message_entity_blockquote import MessageEntityBlockquote
from .input_channel_empty import InputChannelEmpty
from .input_channel import InputChannel
from .input_channel_from_message import InputChannelFromMessage
from .message_range import MessageRange
from .channel_messages_filter_empty import ChannelMessagesFilterEmpty
from .channel_messages_filter import ChannelMessagesFilter
from .channel_participant import ChannelParticipant
from .channel_participant_self import ChannelParticipantSelf
from .channel_participant_creator import ChannelParticipantCreator
from .channel_participant_admin import ChannelParticipantAdmin
from .channel_participant_banned import ChannelParticipantBanned
from .channel_participant_left import ChannelParticipantLeft
from .channel_participants_recent import ChannelParticipantsRecent
from .channel_participants_admins import ChannelParticipantsAdmins
from .channel_participants_kicked import ChannelParticipantsKicked
from .channel_participants_bots import ChannelParticipantsBots
from .channel_participants_banned import ChannelParticipantsBanned
from .channel_participants_search import ChannelParticipantsSearch
from .channel_participants_contacts import ChannelParticipantsContacts
from .channel_participants_mentions import ChannelParticipantsMentions
from .input_bot_inline_message_media_auto import InputBotInlineMessageMediaAuto
from .input_bot_inline_message_text import InputBotInlineMessageText
from .input_bot_inline_message_media_geo import InputBotInlineMessageMediaGeo
from .input_bot_inline_message_media_venue import InputBotInlineMessageMediaVenue
from .input_bot_inline_message_media_contact import InputBotInlineMessageMediaContact
from .input_bot_inline_message_game import InputBotInlineMessageGame
from .input_bot_inline_message_media_invoice import InputBotInlineMessageMediaInvoice
from .input_bot_inline_message_media_web_page import InputBotInlineMessageMediaWebPage
from .input_bot_inline_result import InputBotInlineResult
from .input_bot_inline_result_photo import InputBotInlineResultPhoto
from .input_bot_inline_result_document import InputBotInlineResultDocument
from .input_bot_inline_result_game import InputBotInlineResultGame
from .bot_inline_message_media_auto import BotInlineMessageMediaAuto
from .bot_inline_message_text import BotInlineMessageText
from .bot_inline_message_media_geo import BotInlineMessageMediaGeo
from .bot_inline_message_media_venue import BotInlineMessageMediaVenue
from .bot_inline_message_media_contact import BotInlineMessageMediaContact
from .bot_inline_message_media_invoice import BotInlineMessageMediaInvoice
from .bot_inline_message_media_web_page import BotInlineMessageMediaWebPage
from .bot_inline_result import BotInlineResult
from .bot_inline_media_result import BotInlineMediaResult
from .exported_message_link import ExportedMessageLink
from .message_fwd_header import MessageFwdHeader
from .input_bot_inline_message_id import InputBotInlineMessageID
from .input_bot_inline_message_id64 import InputBotInlineMessageID64
from .inline_bot_switch_pm import InlineBotSwitchPM
from .top_peer import TopPeer
from .top_peer_category_bots_pm import TopPeerCategoryBotsPM
from .top_peer_category_bots_inline import TopPeerCategoryBotsInline
from .top_peer_category_correspondents import TopPeerCategoryCorrespondents
from .top_peer_category_groups import TopPeerCategoryGroups
from .top_peer_category_channels import TopPeerCategoryChannels
from .top_peer_category_phone_calls import TopPeerCategoryPhoneCalls
from .top_peer_category_forward_users import TopPeerCategoryForwardUsers
from .top_peer_category_forward_chats import TopPeerCategoryForwardChats
from .top_peer_category_peers import TopPeerCategoryPeers
from .draft_message_empty import DraftMessageEmpty
from .draft_message import DraftMessage
from .sticker_set_covered import StickerSetCovered
from .sticker_set_multi_covered import StickerSetMultiCovered
from .sticker_set_full_covered import StickerSetFullCovered
from .sticker_set_no_covered import StickerSetNoCovered
from .mask_coords import MaskCoords
from .input_stickered_media_photo import InputStickeredMediaPhoto
from .input_stickered_media_document import InputStickeredMediaDocument
from .game import Game
from .input_game_id import InputGameID
from .input_game_short_name import InputGameShortName
from .high_score import HighScore
from .text_empty import TextEmpty
from .text_plain import TextPlain
from .text_bold import TextBold
from .text_italic import TextItalic
from .text_underline import TextUnderline
from .text_strike import TextStrike
from .text_fixed import TextFixed
from .text_url import TextUrl
from .text_email import TextEmail
from .text_concat import TextConcat
from .text_subscript import TextSubscript
from .text_superscript import TextSuperscript
from .text_marked import TextMarked
from .text_phone import TextPhone
from .text_image import TextImage
from .text_anchor import TextAnchor
from .page_block_unsupported import PageBlockUnsupported
from .page_block_title import PageBlockTitle
from .page_block_subtitle import PageBlockSubtitle
from .page_block_author_date import PageBlockAuthorDate
from .page_block_header import PageBlockHeader
from .page_block_subheader import PageBlockSubheader
from .page_block_paragraph import PageBlockParagraph
from .page_block_preformatted import PageBlockPreformatted
from .page_block_footer import PageBlockFooter
from .page_block_divider import PageBlockDivider
from .page_block_anchor import PageBlockAnchor
from .page_block_list import PageBlockList
from .page_block_blockquote import PageBlockBlockquote
from .page_block_pullquote import PageBlockPullquote
from .page_block_photo import PageBlockPhoto
from .page_block_video import PageBlockVideo
from .page_block_cover import PageBlockCover
from .page_block_embed import PageBlockEmbed
from .page_block_embed_post import PageBlockEmbedPost
from .page_block_collage import PageBlockCollage
from .page_block_slideshow import PageBlockSlideshow
from .page_block_channel import PageBlockChannel
from .page_block_audio import PageBlockAudio
from .page_block_kicker import PageBlockKicker
from .page_block_table import PageBlockTable
from .page_block_ordered_list import PageBlockOrderedList
from .page_block_details import PageBlockDetails
from .page_block_related_articles import PageBlockRelatedArticles
from .page_block_map import PageBlockMap
from .phone_call_discard_reason_missed import PhoneCallDiscardReasonMissed
from .phone_call_discard_reason_disconnect import PhoneCallDiscardReasonDisconnect
from .phone_call_discard_reason_hangup import PhoneCallDiscardReasonHangup
from .phone_call_discard_reason_busy import PhoneCallDiscardReasonBusy
from .data_json import DataJSON
from .labeled_price import LabeledPrice
from .invoice import Invoice
from .payment_charge import PaymentCharge
from .post_address import PostAddress
from .payment_requested_info import PaymentRequestedInfo
from .payment_saved_credentials_card import PaymentSavedCredentialsCard
from .web_document import WebDocument
from .web_document_no_proxy import WebDocumentNoProxy
from .input_web_document import InputWebDocument
from .input_web_file_location import InputWebFileLocation
from .input_web_file_geo_point_location import InputWebFileGeoPointLocation
from .input_web_file_audio_album_thumb_location import InputWebFileAudioAlbumThumbLocation
from .input_payment_credentials_saved import InputPaymentCredentialsSaved
from .input_payment_credentials import InputPaymentCredentials
from .input_payment_credentials_apple_pay import InputPaymentCredentialsApplePay
from .input_payment_credentials_google_pay import InputPaymentCredentialsGooglePay
from .shipping_option import ShippingOption
from .input_sticker_set_item import InputStickerSetItem
from .input_phone_call import InputPhoneCall
from .phone_call_empty import PhoneCallEmpty
from .phone_call_waiting import PhoneCallWaiting
from .phone_call_requested import PhoneCallRequested
from .phone_call_accepted import PhoneCallAccepted
from .phone_call import PhoneCall
from .phone_call_discarded import PhoneCallDiscarded
from .phone_connection import PhoneConnection
from .phone_connection_webrtc import PhoneConnectionWebrtc
from .phone_call_protocol import PhoneCallProtocol
from .cdn_public_key import CdnPublicKey
from .cdn_config import CdnConfig
from .lang_pack_string import LangPackString
from .lang_pack_string_pluralized import LangPackStringPluralized
from .lang_pack_string_deleted import LangPackStringDeleted
from .lang_pack_difference import LangPackDifference
from .lang_pack_language import LangPackLanguage
from .channel_admin_log_event_action_change_title import ChannelAdminLogEventActionChangeTitle
from .channel_admin_log_event_action_change_about import ChannelAdminLogEventActionChangeAbout
from .channel_admin_log_event_action_change_username import ChannelAdminLogEventActionChangeUsername
from .channel_admin_log_event_action_change_photo import ChannelAdminLogEventActionChangePhoto
from .channel_admin_log_event_action_toggle_invites import ChannelAdminLogEventActionToggleInvites
from .channel_admin_log_event_action_toggle_signatures import ChannelAdminLogEventActionToggleSignatures
from .channel_admin_log_event_action_update_pinned import ChannelAdminLogEventActionUpdatePinned
from .channel_admin_log_event_action_edit_message import ChannelAdminLogEventActionEditMessage
from .channel_admin_log_event_action_delete_message import ChannelAdminLogEventActionDeleteMessage
from .channel_admin_log_event_action_participant_join import ChannelAdminLogEventActionParticipantJoin
from .channel_admin_log_event_action_participant_leave import ChannelAdminLogEventActionParticipantLeave
from .channel_admin_log_event_action_participant_invite import ChannelAdminLogEventActionParticipantInvite
from .channel_admin_log_event_action_participant_toggle_ban import ChannelAdminLogEventActionParticipantToggleBan
from .channel_admin_log_event_action_participant_toggle_admin import ChannelAdminLogEventActionParticipantToggleAdmin
from .channel_admin_log_event_action_change_sticker_set import ChannelAdminLogEventActionChangeStickerSet
from .channel_admin_log_event_action_toggle_pre_history_hidden import ChannelAdminLogEventActionTogglePreHistoryHidden
from .channel_admin_log_event_action_default_banned_rights import ChannelAdminLogEventActionDefaultBannedRights
from .channel_admin_log_event_action_stop_poll import ChannelAdminLogEventActionStopPoll
from .channel_admin_log_event_action_change_linked_chat import ChannelAdminLogEventActionChangeLinkedChat
from .channel_admin_log_event_action_change_location import ChannelAdminLogEventActionChangeLocation
from .channel_admin_log_event_action_toggle_slow_mode import ChannelAdminLogEventActionToggleSlowMode
from .channel_admin_log_event_action_start_group_call import ChannelAdminLogEventActionStartGroupCall
from .channel_admin_log_event_action_discard_group_call import ChannelAdminLogEventActionDiscardGroupCall
from .channel_admin_log_event_action_participant_mute import ChannelAdminLogEventActionParticipantMute
from .channel_admin_log_event_action_participant_unmute import ChannelAdminLogEventActionParticipantUnmute
from .channel_admin_log_event_action_toggle_group_call_setting import ChannelAdminLogEventActionToggleGroupCallSetting
from .channel_admin_log_event_action_participant_join_by_invite import ChannelAdminLogEventActionParticipantJoinByInvite
from .channel_admin_log_event_action_exported_invite_delete import ChannelAdminLogEventActionExportedInviteDelete
from .channel_admin_log_event_action_exported_invite_revoke import ChannelAdminLogEventActionExportedInviteRevoke
from .channel_admin_log_event_action_exported_invite_edit import ChannelAdminLogEventActionExportedInviteEdit
from .channel_admin_log_event_action_participant_volume import ChannelAdminLogEventActionParticipantVolume
from .channel_admin_log_event_action_change_history_ttl import ChannelAdminLogEventActionChangeHistoryTTL
from .channel_admin_log_event_action_participant_join_by_request import ChannelAdminLogEventActionParticipantJoinByRequest
from .channel_admin_log_event_action_toggle_no_forwards import ChannelAdminLogEventActionToggleNoForwards
from .channel_admin_log_event_action_send_message import ChannelAdminLogEventActionSendMessage
from .channel_admin_log_event_action_change_available_reactions import ChannelAdminLogEventActionChangeAvailableReactions
from .channel_admin_log_event_action_change_usernames import ChannelAdminLogEventActionChangeUsernames
from .channel_admin_log_event_action_toggle_forum import ChannelAdminLogEventActionToggleForum
from .channel_admin_log_event_action_create_topic import ChannelAdminLogEventActionCreateTopic
from .channel_admin_log_event_action_edit_topic import ChannelAdminLogEventActionEditTopic
from .channel_admin_log_event_action_delete_topic import ChannelAdminLogEventActionDeleteTopic
from .channel_admin_log_event_action_pin_topic import ChannelAdminLogEventActionPinTopic
from .channel_admin_log_event_action_toggle_anti_spam import ChannelAdminLogEventActionToggleAntiSpam
from .channel_admin_log_event_action_change_peer_color import ChannelAdminLogEventActionChangePeerColor
from .channel_admin_log_event_action_change_profile_peer_color import ChannelAdminLogEventActionChangeProfilePeerColor
from .channel_admin_log_event_action_change_wallpaper import ChannelAdminLogEventActionChangeWallpaper
from .channel_admin_log_event_action_change_emoji_status import ChannelAdminLogEventActionChangeEmojiStatus
from .channel_admin_log_event_action_change_emoji_sticker_set import ChannelAdminLogEventActionChangeEmojiStickerSet
from .channel_admin_log_event import ChannelAdminLogEvent
from .channel_admin_log_events_filter import ChannelAdminLogEventsFilter
from .popular_contact import PopularContact
from .recent_me_url_unknown import RecentMeUrlUnknown
from .recent_me_url_user import RecentMeUrlUser
from .recent_me_url_chat import RecentMeUrlChat
from .recent_me_url_chat_invite import RecentMeUrlChatInvite
from .recent_me_url_sticker_set import RecentMeUrlStickerSet
from .input_single_media import InputSingleMedia
from .web_authorization import WebAuthorization
from .input_message_id import InputMessageID
from .input_message_reply_to import InputMessageReplyTo
from .input_message_pinned import InputMessagePinned
from .input_message_callback_query import InputMessageCallbackQuery
from .input_dialog_peer import InputDialogPeer
from .input_dialog_peer_folder import InputDialogPeerFolder
from .dialog_peer import DialogPeer
from .dialog_peer_folder import DialogPeerFolder
from .file_hash import FileHash
from .input_client_proxy import InputClientProxy
from .input_secure_file_uploaded import InputSecureFileUploaded
from .input_secure_file import InputSecureFile
from .secure_file_empty import SecureFileEmpty
from .secure_file import SecureFile
from .secure_data import SecureData
from .secure_plain_phone import SecurePlainPhone
from .secure_plain_email import SecurePlainEmail
from .secure_value_type_personal_details import SecureValueTypePersonalDetails
from .secure_value_type_passport import SecureValueTypePassport
from .secure_value_type_driver_license import SecureValueTypeDriverLicense
from .secure_value_type_identity_card import SecureValueTypeIdentityCard
from .secure_value_type_internal_passport import SecureValueTypeInternalPassport
from .secure_value_type_address import SecureValueTypeAddress
from .secure_value_type_utility_bill import SecureValueTypeUtilityBill
from .secure_value_type_bank_statement import SecureValueTypeBankStatement
from .secure_value_type_rental_agreement import SecureValueTypeRentalAgreement
from .secure_value_type_passport_registration import SecureValueTypePassportRegistration
from .secure_value_type_temporary_registration import SecureValueTypeTemporaryRegistration
from .secure_value_type_phone import SecureValueTypePhone
from .secure_value_type_email import SecureValueTypeEmail
from .secure_value import SecureValue
from .input_secure_value import InputSecureValue
from .secure_value_hash import SecureValueHash
from .secure_value_error_data import SecureValueErrorData
from .secure_value_error_front_side import SecureValueErrorFrontSide
from .secure_value_error_reverse_side import SecureValueErrorReverseSide
from .secure_value_error_selfie import SecureValueErrorSelfie
from .secure_value_error_file import SecureValueErrorFile
from .secure_value_error_files import SecureValueErrorFiles
from .secure_value_error import SecureValueError
from .secure_value_error_translation_file import SecureValueErrorTranslationFile
from .secure_value_error_translation_files import SecureValueErrorTranslationFiles
from .secure_credentials_encrypted import SecureCredentialsEncrypted
from .saved_phone_contact import SavedPhoneContact
from .password_kdf_algo_unknown import PasswordKdfAlgoUnknown
from .password_kdf_algo_sha256_sha256_pbkdf2_hmacsha512iter100000_sha256_mod_pow import PasswordKdfAlgoSHA256SHA256PBKDF2HMACSHA512iter100000SHA256ModPow
from .secure_password_kdf_algo_unknown import SecurePasswordKdfAlgoUnknown
from .secure_password_kdf_algo_pbkdf2_hmacsha512iter100000 import SecurePasswordKdfAlgoPBKDF2HMACSHA512iter100000
from .secure_password_kdf_algo_sha512 import SecurePasswordKdfAlgoSHA512
from .secure_secret_settings import SecureSecretSettings
from .input_check_password_empty import InputCheckPasswordEmpty
from .input_check_password_srp import InputCheckPasswordSRP
from .secure_required_type import SecureRequiredType
from .secure_required_type_one_of import SecureRequiredTypeOneOf
from .input_app_event import InputAppEvent
from .json_object_value import JsonObjectValue
from .json_null import JsonNull
from .json_bool import JsonBool
from .json_number import JsonNumber
from .json_string import JsonString
from .json_array import JsonArray
from .json_object import JsonObject
from .page_table_cell import PageTableCell
from .page_table_row import PageTableRow
from .page_caption import PageCaption
from .page_list_item_text import PageListItemText
from .page_list_item_blocks import PageListItemBlocks
from .page_list_ordered_item_text import PageListOrderedItemText
from .page_list_ordered_item_blocks import PageListOrderedItemBlocks
from .page_related_article import PageRelatedArticle
from .page import Page
from .poll_answer import PollAnswer
from .poll import Poll
from .poll_answer_voters import PollAnswerVoters
from .poll_results import PollResults
from .chat_onlines import ChatOnlines
from .stats_url import StatsURL
from .chat_admin_rights import ChatAdminRights
from .chat_banned_rights import ChatBannedRights
from .input_wall_paper import InputWallPaper
from .input_wall_paper_slug import InputWallPaperSlug
from .input_wall_paper_no_file import InputWallPaperNoFile
from .code_settings import CodeSettings
from .wall_paper_settings import WallPaperSettings
from .auto_download_settings import AutoDownloadSettings
from .emoji_keyword import EmojiKeyword
from .emoji_keyword_deleted import EmojiKeywordDeleted
from .emoji_keywords_difference import EmojiKeywordsDifference
from .emoji_url import EmojiURL
from .emoji_language import EmojiLanguage
from .folder import Folder
from .input_folder_peer import InputFolderPeer
from .folder_peer import FolderPeer
from .url_auth_result_request import UrlAuthResultRequest
from .url_auth_result_accepted import UrlAuthResultAccepted
from .url_auth_result_default import UrlAuthResultDefault
from .channel_location_empty import ChannelLocationEmpty
from .channel_location import ChannelLocation
from .peer_located import PeerLocated
from .peer_self_located import PeerSelfLocated
from .restriction_reason import RestrictionReason
from .input_theme import InputTheme
from .input_theme_slug import InputThemeSlug
from .theme import Theme
from .base_theme_classic import BaseThemeClassic
from .base_theme_day import BaseThemeDay
from .base_theme_night import BaseThemeNight
from .base_theme_tinted import BaseThemeTinted
from .base_theme_arctic import BaseThemeArctic
from .input_theme_settings import InputThemeSettings
from .theme_settings import ThemeSettings
from .web_page_attribute_theme import WebPageAttributeTheme
from .web_page_attribute_story import WebPageAttributeStory
from .bank_card_open_url import BankCardOpenUrl
from .dialog_filter import DialogFilter
from .dialog_filter_default import DialogFilterDefault
from .dialog_filter_chatlist import DialogFilterChatlist
from .dialog_filter_suggested import DialogFilterSuggested
from .stats_date_range_days import StatsDateRangeDays
from .stats_abs_value_and_prev import StatsAbsValueAndPrev
from .stats_percent_value import StatsPercentValue
from .stats_graph_async import StatsGraphAsync
from .stats_graph_error import StatsGraphError
from .stats_graph import StatsGraph
from .video_size import VideoSize
from .video_size_emoji_markup import VideoSizeEmojiMarkup
from .video_size_sticker_markup import VideoSizeStickerMarkup
from .stats_group_top_poster import StatsGroupTopPoster
from .stats_group_top_admin import StatsGroupTopAdmin
from .stats_group_top_inviter import StatsGroupTopInviter
from .global_privacy_settings import GlobalPrivacySettings
from .message_views import MessageViews
from .message_reply_header import MessageReplyHeader
from .message_reply_story_header import MessageReplyStoryHeader
from .message_replies import MessageReplies
from .peer_blocked import PeerBlocked
from .group_call_discarded import GroupCallDiscarded
from .group_call import GroupCall
from .input_group_call import InputGroupCall
from .group_call_participant import GroupCallParticipant
from .inline_query_peer_type_same_bot_pm import InlineQueryPeerTypeSameBotPM
from .inline_query_peer_type_pm import InlineQueryPeerTypePM
from .inline_query_peer_type_chat import InlineQueryPeerTypeChat
from .inline_query_peer_type_megagroup import InlineQueryPeerTypeMegagroup
from .inline_query_peer_type_broadcast import InlineQueryPeerTypeBroadcast
from .inline_query_peer_type_bot_pm import InlineQueryPeerTypeBotPM
from .chat_invite_importer import ChatInviteImporter
from .chat_admin_with_invites import ChatAdminWithInvites
from .group_call_participant_video_source_group import GroupCallParticipantVideoSourceGroup
from .group_call_participant_video import GroupCallParticipantVideo
from .bot_command_scope_default import BotCommandScopeDefault
from .bot_command_scope_users import BotCommandScopeUsers
from .bot_command_scope_chats import BotCommandScopeChats
from .bot_command_scope_chat_admins import BotCommandScopeChatAdmins
from .bot_command_scope_peer import BotCommandScopePeer
from .bot_command_scope_peer_admins import BotCommandScopePeerAdmins
from .bot_command_scope_peer_user import BotCommandScopePeerUser
from .sponsored_message import SponsoredMessage
from .search_results_calendar_period import SearchResultsCalendarPeriod
from .search_result_position import SearchResultPosition
from .reaction_count import ReactionCount
from .message_reactions import MessageReactions
from .available_reaction import AvailableReaction
from .message_peer_reaction import MessagePeerReaction
from .group_call_stream_channel import GroupCallStreamChannel
from .attach_menu_bot_icon_color import AttachMenuBotIconColor
from .attach_menu_bot_icon import AttachMenuBotIcon
from .attach_menu_bot import AttachMenuBot
from .attach_menu_bots_not_modified import AttachMenuBotsNotModified
from .attach_menu_bots import AttachMenuBots
from .attach_menu_bots_bot import AttachMenuBotsBot
from .web_view_result_url import WebViewResultUrl
from .simple_web_view_result_url import SimpleWebViewResultUrl
from .web_view_message_sent import WebViewMessageSent
from .bot_menu_button_default import BotMenuButtonDefault
from .bot_menu_button_commands import BotMenuButtonCommands
from .bot_menu_button import BotMenuButton
from .notification_sound_default import NotificationSoundDefault
from .notification_sound_none import NotificationSoundNone
from .notification_sound_local import NotificationSoundLocal
from .notification_sound_ringtone import NotificationSoundRingtone
from .attach_menu_peer_type_same_bot_pm import AttachMenuPeerTypeSameBotPM
from .attach_menu_peer_type_bot_pm import AttachMenuPeerTypeBotPM
from .attach_menu_peer_type_pm import AttachMenuPeerTypePM
from .attach_menu_peer_type_chat import AttachMenuPeerTypeChat
from .attach_menu_peer_type_broadcast import AttachMenuPeerTypeBroadcast
from .input_invoice_message import InputInvoiceMessage
from .input_invoice_slug import InputInvoiceSlug
from .input_invoice_premium_gift_code import InputInvoicePremiumGiftCode
from .input_store_payment_premium_subscription import InputStorePaymentPremiumSubscription
from .input_store_payment_gift_premium import InputStorePaymentGiftPremium
from .input_store_payment_premium_gift_code import InputStorePaymentPremiumGiftCode
from .input_store_payment_premium_giveaway import InputStorePaymentPremiumGiveaway
from .premium_gift_option import PremiumGiftOption
from .payment_form_method import PaymentFormMethod
from .emoji_status_empty import EmojiStatusEmpty
from .emoji_status import EmojiStatus
from .emoji_status_until import EmojiStatusUntil
from .reaction_empty import ReactionEmpty
from .reaction_emoji import ReactionEmoji
from .reaction_custom_emoji import ReactionCustomEmoji
from .chat_reactions_none import ChatReactionsNone
from .chat_reactions_all import ChatReactionsAll
from .chat_reactions_some import ChatReactionsSome
from .email_verify_purpose_login_setup import EmailVerifyPurposeLoginSetup
from .email_verify_purpose_login_change import EmailVerifyPurposeLoginChange
from .email_verify_purpose_passport import EmailVerifyPurposePassport
from .email_verification_code import EmailVerificationCode
from .email_verification_google import EmailVerificationGoogle
from .email_verification_apple import EmailVerificationApple
from .premium_subscription_option import PremiumSubscriptionOption
from .send_as_peer import SendAsPeer
from .message_extended_media_preview import MessageExtendedMediaPreview
from .message_extended_media import MessageExtendedMedia
from .sticker_keyword import StickerKeyword
from .username import Username
from .forum_topic_deleted import ForumTopicDeleted
from .forum_topic import ForumTopic
from .default_history_ttl import DefaultHistoryTTL
from .exported_contact_token import ExportedContactToken
from .request_peer_type_user import RequestPeerTypeUser
from .request_peer_type_chat import RequestPeerTypeChat
from .request_peer_type_broadcast import RequestPeerTypeBroadcast
from .emoji_list_not_modified import EmojiListNotModified
from .emoji_list import EmojiList
from .emoji_group import EmojiGroup
from .text_with_entities import TextWithEntities
from .auto_save_settings import AutoSaveSettings
from .auto_save_exception import AutoSaveException
from .input_bot_app_id import InputBotAppID
from .input_bot_app_short_name import InputBotAppShortName
from .bot_app_not_modified import BotAppNotModified
from .bot_app import BotApp
from .app_web_view_result_url import AppWebViewResultUrl
from .inline_bot_web_view import InlineBotWebView
from .read_participant_date import ReadParticipantDate
from .input_chatlist_dialog_filter import InputChatlistDialogFilter
from .exported_chatlist_invite import ExportedChatlistInvite
from .message_peer_vote import MessagePeerVote
from .message_peer_vote_input_option import MessagePeerVoteInputOption
from .message_peer_vote_multiple import MessagePeerVoteMultiple
from .sponsored_web_page import SponsoredWebPage
from .story_views import StoryViews
from .story_item_deleted import StoryItemDeleted
from .story_item_skipped import StoryItemSkipped
from .story_item import StoryItem
from .story_view import StoryView
from .story_view_public_forward import StoryViewPublicForward
from .story_view_public_repost import StoryViewPublicRepost
from .input_reply_to_message import InputReplyToMessage
from .input_reply_to_story import InputReplyToStory
from .exported_story_link import ExportedStoryLink
from .stories_stealth_mode import StoriesStealthMode
from .media_area_coordinates import MediaAreaCoordinates
from .media_area_venue import MediaAreaVenue
from .input_media_area_venue import InputMediaAreaVenue
from .media_area_geo_point import MediaAreaGeoPoint
from .media_area_suggested_reaction import MediaAreaSuggestedReaction
from .media_area_channel_post import MediaAreaChannelPost
from .input_media_area_channel_post import InputMediaAreaChannelPost
from .peer_stories import PeerStories
from .premium_gift_code_option import PremiumGiftCodeOption
from .prepaid_giveaway import PrepaidGiveaway
from .boost import Boost
from .my_boost import MyBoost
from .story_fwd_header import StoryFwdHeader
from .post_interaction_counters_message import PostInteractionCountersMessage
from .post_interaction_counters_story import PostInteractionCountersStory
from .public_forward_message import PublicForwardMessage
from .public_forward_story import PublicForwardStory
from .peer_color import PeerColor
from .story_reaction import StoryReaction
from .story_reaction_public_forward import StoryReactionPublicForward
from .story_reaction_public_repost import StoryReactionPublicRepost
from .saved_dialog import SavedDialog
from .saved_reaction_tag import SavedReactionTag
from .outbox_read_date import OutboxReadDate
from .sms_job import SmsJob
from .business_weekly_open import BusinessWeeklyOpen
from .business_work_hours import BusinessWorkHours
from .business_location import BusinessLocation
from .input_business_recipients import InputBusinessRecipients
from .business_recipients import BusinessRecipients
from .business_away_message_schedule_always import BusinessAwayMessageScheduleAlways
from .business_away_message_schedule_outside_work_hours import BusinessAwayMessageScheduleOutsideWorkHours
from .business_away_message_schedule_custom import BusinessAwayMessageScheduleCustom
from .input_business_greeting_message import InputBusinessGreetingMessage
from .business_greeting_message import BusinessGreetingMessage
from .input_business_away_message import InputBusinessAwayMessage
from .business_away_message import BusinessAwayMessage
from .timezone import Timezone
from .quick_reply import QuickReply
from .input_quick_reply_shortcut import InputQuickReplyShortcut
from .input_quick_reply_shortcut_id import InputQuickReplyShortcutId
from .connected_bot import ConnectedBot
from .birthday import Birthday
from .bot_business_connection import BotBusinessConnection
from .input_business_intro import InputBusinessIntro
from .business_intro import BusinessIntro
from .input_collectible_username import InputCollectibleUsername
from .input_collectible_phone import InputCollectiblePhone
from .input_business_bot_recipients import InputBusinessBotRecipients
from .business_bot_recipients import BusinessBotRecipients
from .contact_birthday import ContactBirthday
from .missing_invitee import MissingInvitee
from .input_business_chat_link import InputBusinessChatLink
from .business_chat_link import BusinessChatLink
from .requested_peer_user import RequestedPeerUser
from .requested_peer_chat import RequestedPeerChat
from .requested_peer_channel import RequestedPeerChannel
from .sponsored_message_report_option import SponsoredMessageReportOption
from .broadcast_revenue_transaction_proceeds import BroadcastRevenueTransactionProceeds
from .broadcast_revenue_transaction_withdrawal import BroadcastRevenueTransactionWithdrawal
from .broadcast_revenue_transaction_refund import BroadcastRevenueTransactionRefund
from . import help, storage, auth, contacts, messages, updates, photos, upload, account, channels, payments, phone, stats, stickers, users, chatlists, bots, stories, premium, smsjobs, fragment



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class MessageEditData(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.messages.MessageEditData`.

    Details:
        - Layer: ``177``
        - ID: ``26B5DDE6``

    Parameters:
        caption (``bool``, *optional*):
            N/A

    Functions:
        This object can be returned by 1 function.

        .. currentmodule:: pyrogram.raw.functions

        .. autosummary::
            :nosignatures:

            messages.GetMessageEditData
    """

    __slots__: List[str] = ["caption"]

    ID = 0x26b5dde6
    QUALNAME = "types.messages.MessageEditData"

    def __init__(self, *, caption: Optional[bool] = None) -> None:
        self.caption = caption  # flags.0?true

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "MessageEditData":
        
        flags = Int.read(b)
        
        caption = True if flags & (1 << 0) else False
        return MessageEditData(caption=caption)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 0) if self.caption else 0
        b.write(Int(flags))
        
        return b.getvalue()



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #

from typing import Union
from pyrogram import raw
from pyrogram.raw.core import TLObject

MessagesFilter = Union[raw.types.InputMessagesFilterChatPhotos, raw.types.InputMessagesFilterContacts, raw.types.InputMessagesFilterDocument, raw.types.InputMessagesFilterEmpty, raw.types.InputMessagesFilterGeo, raw.types.InputMessagesFilterGif, raw.types.InputMessagesFilterMusic, raw.types.InputMessagesFilterMyMentions, raw.types.InputMessagesFilterPhoneCalls, raw.types.InputMessagesFilterPhotoVideo, raw.types.InputMessagesFilterPhotos, raw.types.InputMessagesFilterPinned, raw.types.InputMessagesFilterRoundVideo, raw.types.InputMessagesFilterRoundVoice, raw.types.InputMessagesFilterUrl, raw.types.InputMessagesFilterVideo, raw.types.InputMessagesFilterVoice]


# noinspection PyRedeclaration
class MessagesFilter:  # type: ignore
    """Telegram API base type.

    Constructors:
        This base type has 17 constructors available.

        .. currentmodule:: pyrogram.raw.types

        .. autosummary::
            :nosignatures:

            InputMessagesFilterChatPhotos
            InputMessagesFilterContacts
            InputMessagesFilterDocument
            InputMessagesFilterEmpty
            InputMessagesFilterGeo
            InputMessagesFilterGif
            InputMessagesFilterMusic
            InputMessagesFilterMyMentions
            InputMessagesFilterPhoneCalls
            InputMessagesFilterPhotoVideo
            InputMessagesFilterPhotos
            InputMessagesFilterPinned
            InputMessagesFilterRoundVideo
            InputMessagesFilterRoundVoice
            InputMessagesFilterUrl
            InputMessagesFilterVideo
            InputMessagesFilterVoice
    """

    QUALNAME = "pyrogram.raw.base.MessagesFilter"

    def __init__(self):
        raise TypeError("Base types can only be used for type checking purposes: "
                        "you tried to use a base type instance as argument, "
                        "but you need to instantiate one of its constructors instead. "
                        "More info: https://pyrofork.mayuri.my.id/telegram/base/messages-filter")



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from pyrogram.raw.core import Message, MsgContainer, TLObject
from pyrogram.raw.functions import Ping
from pyrogram.raw.types import MsgsAck, HttpWait
from .msg_id import MsgId
from .seq_no import SeqNo

not_content_related = (Ping, HttpWait, MsgsAck, MsgContainer)


class MsgFactory:
    def __init__(self):
        self.seq_no = SeqNo()

    def __call__(self, body: TLObject) -> Message:
        return Message(
            body,
            MsgId(),
            self.seq_no(not isinstance(body, not_content_related)),
            len(body)
        )



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from enum import auto

from .auto_name import AutoName


class ChatType(AutoName):
    """Chat type enumeration used in :obj:`~pyrogram.types.Chat`."""

    PRIVATE = auto()
    "Chat is a private chat with a user"

    BOT = auto()
    "Chat is a private chat with a bot"

    GROUP = auto()
    "Chat is a basic group"

    SUPERGROUP = auto()
    "Chat is a supergroup"

    CHANNEL = auto()
    "Chat is a channel"



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

import logging
from typing import Union, Optional, AsyncGenerator

import pyrogram
from pyrogram import raw
from pyrogram import types
from pyrogram import utils

log = logging.getLogger(__name__)


class GetForumTopics:
    async def get_forum_topics(
        self: "pyrogram.Client",
        chat_id: Union[int, str],
        limit: int = 0
    ) -> Optional[AsyncGenerator["types.ForumTopic", None]]:
        """Get one or more topic from a chat.

        .. include:: /_includes/usable-by/users.rst

        Parameters:
            chat_id (``int`` | ``str``):
                Unique identifier (int) or username (str) of the target chat.
                You can also use chat public link in form of *t.me/<username>* (str).

            limit (``int``, *optional*):
                Limits the number of topics to be retrieved.

        Returns:
            ``Generator``: On success, a generator yielding :obj:`~pyrogram.types.ForumTopic` objects is returned.

        Example:
            .. code-block:: python

                # get all forum topics
                async for topic in app.get_forum_topics(chat_id):
                    print(topic)

        Raises:
            ValueError: In case of invalid arguments.
        """

        peer = await self.resolve_peer(chat_id)

        rpc = raw.functions.channels.GetForumTopics(channel=peer, offset_date=0, offset_id=0, offset_topic=0, limit=limit)

        r = await self.invoke(rpc, sleep_threshold=-1)

        for _topic in r.topics:
            yield types.ForumTopic._parse(_topic)



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

import pyrogram

from typing import List
from pyrogram.types import Identifier, Listener

class GetManyListenersMatchingWithData:
    def get_many_listeners_matching_with_data(
        self: "pyrogram.Client",
        data: Identifier,
        listener_type: "pyrogram.enums.ListenerTypes",
    ) -> List[Listener]:
        """Gets multiple listener that matches the given data.

        .. include:: /_includes/usable-by/users-bots.rst

        Parameters:
            data (:obj:`~pyrogram.types.Identifier`):
                The Identifier to match agains.

            listener_type (:obj:`~pyrogram.enums.ListenerTypes`):
                The type of listener to get.

        Returns:
            List of :obj:`~pyrogram.types.Listener`: On success, a list of Listener is returned.
        """
        listeners = []
        for listener in self.listeners[listener_type]:
            if listener.identifier.matches(data):
                listeners.append(listener)
        return listeners



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from hashlib import sha256
from io import BytesIO
from os import urandom

from pyrogram.errors import SecurityCheckMismatch
from pyrogram.raw.core import Message, Long
from . import aes


def kdf(auth_key: bytes, msg_key: bytes, outgoing: bool) -> tuple:
    # https://core.telegram.org/mtproto/description#defining-aes-key-and-initialization-vector
    x = 0 if outgoing else 8

    sha256_a = sha256(msg_key + auth_key[x: x + 36]).digest()
    sha256_b = sha256(auth_key[x + 40:x + 76] + msg_key).digest()  # 76 = 40 + 36

    aes_key = sha256_a[:8] + sha256_b[8:24] + sha256_a[24:32]
    aes_iv = sha256_b[:8] + sha256_a[8:24] + sha256_b[24:32]

    return aes_key, aes_iv


def pack(message: Message, salt: int, session_id: bytes, auth_key: bytes, auth_key_id: bytes) -> bytes:
    data = Long(salt) + session_id + message.write()
    padding = urandom(-(len(data) + 12) % 16 + 12)

    # 88 = 88 + 0 (outgoing message)
    msg_key_large = sha256(auth_key[88: 88 + 32] + data + padding).digest()
    msg_key = msg_key_large[8:24]
    aes_key, aes_iv = kdf(auth_key, msg_key, True)

    return auth_key_id + msg_key + aes.ige256_encrypt(data + padding, aes_key, aes_iv)


def unpack(
    b: BytesIO,
    session_id: bytes,
    auth_key: bytes,
    auth_key_id: bytes
) -> Message:
    SecurityCheckMismatch.check(b.read(8) == auth_key_id, "b.read(8) == auth_key_id")

    msg_key = b.read(16)
    aes_key, aes_iv = kdf(auth_key, msg_key, False)
    data = BytesIO(aes.ige256_decrypt(b.read(), aes_key, aes_iv))
    data.read(8)  # Salt

    # https://core.telegram.org/mtproto/security_guidelines#checking-session-id
    SecurityCheckMismatch.check(data.read(8) == session_id, "data.read(8) == session_id")

    try:
        message = Message.read(data)
    except KeyError as e:
        if e.args[0] == 0:
            raise ConnectionError(f"Received empty data. Check your internet connection.")

        left = data.read().hex()

        left = [left[i:i + 64] for i in range(0, len(left), 64)]
        left = [[left[i:i + 8] for i in range(0, len(left), 8)] for left in left]
        left = "\n".join(" ".join(x for x in left) for left in left)

        raise ValueError(f"The server sent an unknown constructor: {hex(e.args[0])}\n{left}")

    # https://core.telegram.org/mtproto/security_guidelines#checking-sha256-hash-value-of-msg-key
    # 96 = 88 + 8 (incoming message)
    SecurityCheckMismatch.check(
        msg_key == sha256(auth_key[96:96 + 32] + data.getvalue()).digest()[8:24],
        "msg_key == sha256(auth_key[96:96 + 32] + data.getvalue()).digest()[8:24]"
    )

    # https://core.telegram.org/mtproto/security_guidelines#checking-message-length
    data.seek(32)  # Get to the payload, skip salt (8) + session_id (8) + msg_id (8) + seq_no (4) + length (4)
    payload = data.read()
    padding = payload[message.length:]
    SecurityCheckMismatch.check(12 <= len(padding) <= 1024, "12 <= len(padding) <= 1024")
    SecurityCheckMismatch.check(len(payload) % 4 == 0, "len(payload) % 4 == 0")

    # https://core.telegram.org/mtproto/security_guidelines#checking-msg-id
    SecurityCheckMismatch.check(message.msg_id % 2 != 0, "message.msg_id % 2 != 0")

    return message



#  FORK PYROFORK <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from pyrogram.raw.core import TLObject
from pyrogram import raw
from typing import List, Optional, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class PaymentForm(TLObject):  # type: ignore
    """Telegram API type.

    Constructor of :obj:`~pyrogram.raw.base.payments.PaymentForm`.

    Details:
        - Layer: ``177``
        - ID: ``A0058751``

    Parameters:
        form_id (``int`` ``64-bit``):
            N/A

        bot_id (``int`` ``64-bit``):
            N/A

        title (``str``):
            N/A

        description (``str``):
            N/A

        invoice (:obj:`Invoice <pyrogram.raw.base.Invoice>`):
            N/A

        provider_id (``int`` ``64-bit``):
            N/A

        url (``str``):
            N/A

        users (List of :obj:`User <pyrogram.raw.base.User>`):
            N/A

        can_save_credentials (``bool``, *optional*):
            N/A

        password_missing (``bool``, *optional*):
            N/A

        photo (:obj:`WebDocument <pyrogram.raw.base.WebDocument>`, *optional*):
            N/A

        native_provider (``str``, *optional*):
            N/A

        native_params (:obj:`DataJSON <pyrogram.raw.base.DataJSON>`, *optional*):
            N/A

        additional_methods (List of :obj:`PaymentFormMethod <pyrogram.raw.base.PaymentFormMethod>`, *optional*):
            N/A

        saved_info (:obj:`PaymentRequestedInfo <pyrogram.raw.base.PaymentRequestedInfo>`, *optional*):
            N/A

        saved_credentials (List of :obj:`PaymentSavedCredentials <pyrogram.raw.base.PaymentSavedCredentials>`, *optional*):
            N/A

    Functions:
        This object can be returned by 1 function.

        .. currentmodule:: pyrogram.raw.functions

        .. autosummary::
            :nosignatures:

            payments.GetPaymentForm
    """

    __slots__: List[str] = ["form_id", "bot_id", "title", "description", "invoice", "provider_id", "url", "users", "can_save_credentials", "password_missing", "photo", "native_provider", "native_params", "additional_methods", "saved_info", "saved_credentials"]

    ID = 0xa0058751
    QUALNAME = "types.payments.PaymentForm"

    def __init__(self, *, form_id: int, bot_id: int, title: str, description: str, invoice: "raw.base.Invoice", provider_id: int, url: str, users: List["raw.base.User"], can_save_credentials: Optional[bool] = None, password_missing: Optional[bool] = None, photo: "raw.base.WebDocument" = None, native_provider: Optional[str] = None, native_params: "raw.base.DataJSON" = None, additional_methods: Optional[List["raw.base.PaymentFormMethod"]] = None, saved_info: "raw.base.PaymentRequestedInfo" = None, saved_credentials: Optional[List["raw.base.PaymentSavedCredentials"]] = None) -> None:
        self.form_id = form_id  # long
        self.bot_id = bot_id  # long
        self.title = title  # string
        self.description = description  # string
        self.invoice = invoice  # Invoice
        self.provider_id = provider_id  # long
        self.url = url  # string
        self.users = users  # Vector<User>
        self.can_save_credentials = can_save_credentials  # flags.2?true
        self.password_missing = password_missing  # flags.3?true
        self.photo = photo  # flags.5?WebDocument
        self.native_provider = native_provider  # flags.4?string
        self.native_params = native_params  # flags.4?DataJSON
        self.additional_methods = additional_methods  # flags.6?Vector<PaymentFormMethod>
        self.saved_info = saved_info  # flags.0?PaymentRequestedInfo
        self.saved_credentials = saved_credentials  # flags.1?Vector<PaymentSavedCredentials>

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "PaymentForm":
        
        flags = Int.read(b)
        
        can_save_credentials = True if flags & (1 << 2) else False
        password_missing = True if flags & (1 << 3) else False
        form_id = Long.read(b)
        
        bot_id = Long.read(b)
        
        title = String.read(b)
        
        description = String.read(b)
        
        photo = TLObject.read(b) if flags & (1 << 5) else None
        
        invoice = TLObject.read(b)
        
        provider_id = Long.read(b)
        
        url = String.read(b)
        
        native_provider = String.read(b) if flags & (1 << 4) else None
        native_params = TLObject.read(b) if flags & (1 << 4) else None
        
        additional_methods = TLObject.read(b) if flags & (1 << 6) else []
        
        saved_info = TLObject.read(b) if flags & (1 << 0) else None
        
        saved_credentials = TLObject.read(b) if flags & (1 << 1) else []
        
        users = TLObject.read(b)
        
        return PaymentForm(form_id=form_id, bot_id=bot_id, title=title, description=description, invoice=invoice, provider_id=provider_id, url=url, users=users, can_save_credentials=can_save_credentials, password_missing=password_missing, photo=photo, native_provider=native_provider, native_params=native_params, additional_methods=additional_methods, saved_info=saved_info, saved_credentials=saved_credentials)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        flags = 0
        flags |= (1 << 2) if self.can_save_credentials else 0
        flags |= (1 << 3) if self.password_missing else 0
        flags |= (1 << 5) if self.photo is not None else 0
        flags |= (1 << 4) if self.native_provider is not None else 0
        flags |= (1 << 4) if self.native_params is not None else 0
        flags |= (1 << 6) if self.additional_methods else 0
        flags |= (1 << 0) if self.saved_info is not None else 0
        flags |= (1 << 1) if self.saved_credentials else 0
        b.write(Int(flags))
        
        b.write(Long(self.form_id))
        
        b.write(Long(self.bot_id))
        
        b.write(String(self.title))
        
        b.write(String(self.description))
        
        if self.photo is not None:
            b.write(self.photo.write())
        
        b.write(self.invoice.write())
        
        b.write(Long(self.provider_id))
        
        b.write(String(self.url))
        
        if self.native_provider is not None:
            b.write(String(self.native_provider))
        
        if self.native_params is not None:
            b.write(self.native_params.write())
        
        if self.additional_methods is not None:
            b.write(Vector(self.additional_methods))
        
        if self.saved_info is not None:
            b.write(self.saved_info.write())
        
        if self.saved_credentials is not None:
            b.write(Vector(self.saved_credentials))
        
        b.write(Vector(self.users))
        
        return b.getvalue()
